<?php
/** Igbo (Igbo)
 *
 * See MessagesQqq.php for message documentation incl. usage of parameters
 * To improve a translation please visit http://translatewiki.net
 *
 * @ingroup Language
 * @file
 *
 * @author Reedy
 * @author Ukabia
 */

$namespaceNames = array(
	NS_MEDIA            => 'Midia',
	NS_SPECIAL          => 'Ihü_kárírí',
	NS_TALK             => 'Okwu',
	NS_USER             => 'Ọbanife',
	NS_USER_TALK        => 'Okwu_ọbanife',
	NS_PROJECT_TALK     => 'Okwu_$1',
	NS_FILE             => 'Usòrò',
	NS_FILE_TALK        => 'Okwu_usòrò',
	NS_MEDIAWIKI        => 'MidiaWiki',
	NS_MEDIAWIKI_TALK   => 'Okwu_MidiaWiki',
	NS_TEMPLATE         => 'Àtụ',
	NS_TEMPLATE_TALK    => 'Okwu_àtụ',
	NS_HELP             => 'Nkwadọ',
	NS_HELP_TALK        => 'Okwu_nkwadọ',
	NS_CATEGORY         => 'Òtù',
	NS_CATEGORY_TALK    => 'Okwu_òtù',
);

$namespaceAliases = array(
	'Nká'                  => NS_MEDIA,
	'Ọ\'bànifé'            => NS_USER,
	'Okwu_ọ\'bànifé'       => NS_USER_TALK,
	'Ákwúkwó_orünotu'      => NS_FILE,
	'Okwu_ákwúkwó_orünotu' => NS_FILE_TALK,
	'NkáWiki'              => NS_MEDIAWIKI,
	'Okwu_NkáWiki'         => NS_MEDIAWIKI_TALK,
	'Nkwádọ'               => NS_HELP,
	'Okwu_nkwádọ'          => NS_HELP_TALK,
	'Ébéonọr'              => NS_CATEGORY,
	'Okwu_ébéonọr'         => NS_CATEGORY_TALK,
);

$specialPageAliases = array(
	'Allpages'                  => array( 'IhüNílé' ),
	'Blankpage'                 => array( 'HịcháIhü' ),
	'Export'                    => array( 'MēKọFùtá' ),
	'Filepath'                  => array( 'UzọrAkwúkwóOrünotu' ),
	'Import'                    => array( 'BàÍfé' ),
	'Mypage'                    => array( 'IhüNkèm' ),
	'Mytalk'                    => array( 'OkwuNkèm' ),
	'Preferences'               => array( 'Ọtúm_dọsẹrẹ_ihem' ),
	'Specialpages'              => array( 'IhüKá' ),
	'Undelete'                  => array( 'Ábàkàshịkwàlà' ),
	'Upload'                    => array( 'TinyéIheNélú' ),
	'Userlogin'                 => array( 'Ọ\'bàniféÍBànyé' ),
	'Userlogout'                => array( 'Ọ\'bàniféÍFụtá' ),
);

$magicWords = array(
	'redirect'                => array( '0', '#KÚFÙ', '#REDIRECT' ),
	'fullpagename'            => array( '1', 'ÁHÀNÍLÉNKÈIHÜ', 'FULLPAGENAME' ),
	'msg'                     => array( '0', 'OZI:', 'MSG:' ),
	'img_right'               => array( '1', 'áká_ịkẹngạ', 'right' ),
	'img_left'                => array( '1', 'áká_èkpè', 'left' ),
	'img_top'                 => array( '1', 'élú', 'top' ),
	'img_middle'              => array( '1', 'ẹtítì', 'middle' ),
	'img_text_bottom'         => array( '1', 'okpúrù-ede', 'text-bottom' ),
	'displaytitle'            => array( '1', 'ZIÍSHÍ', 'DISPLAYTITLE' ),
	'pagesize'                => array( '1', 'ÀSÁIHÜ', 'PAGESIZE' ),
);

$messages = array(
# User preference toggles
'tog-underline'               => 'Okpürụ ahiri jikodo:',
'tog-highlightbroken'         => 'Rütá jikodo gbajịrị <a href="" class"ohúrù">otuá</a> (nke ozor: otuá<a href="" class="ime">?</a>)',
'tog-justify'                 => 'Tinyé ndelita na ọkwa',
'tog-hideminor'               => 'Zonari orü ntàkírí na nwerue mẹrẹ ogẹ nsó',
'tog-hidepatrolled'           => 'Zonari orü ha hụrụ na nwerue mẹrẹ ogẹ nsó',
'tog-newpageshidepatrolled'   => 'Zonari orü ha hụrụ shí ndetu ihü ohúrù',
'tog-extendwatchlist'         => 'Gbasa ndetu ihe ánà elé ka ó zi gbanwere nke níle, o bughi nani nke isi nso',
'tog-usenewrc'                => 'Ji ihe gbanwere nso níguélé élu (ö chọrọ JavaScript)',
'tog-numberheadings'          => 'Onuogụgụ-otu anyi mere ya maka ishi edemede',
'tog-showtoolbar'             => 'Zi igbe orü (Í gí nwere JavaScript)',
'tog-editondblclick'          => 'Rüwá na élu ihü mgbe I kpạtạrạ (ö chọrọ JavaScript)',
'tog-editsection'             => 'Gbanyé orürü nkeji shi [rüwá] jikodo',
'tog-editsectiononrightclick' => 'Kpa na áká nri Í gbanyé orürü nkeji na ishi nkeji (ö chọrọ JavaScript)',
'tog-showtoc'                 => 'Zi agada ihe níle (maka ihü nwere ishis ká áto)',
'tog-rememberpassword'        => 'Chetá edemede éjim a banyé na orunótuá (nke ukwu nke rürü {{PLURAL:$1|chi|chi}} $1)',
'tog-watchcreations'          => 'Tinyé ihüm na eké na ndetu ihem ne lé',
'tog-watchdefault'            => 'Tinyé ihü m na rüoru élu na ndetu ihem ne lé',
'tog-watchmoves'              => 'Tinyé ihü m na puzié na ndetu ihe m ne lé',
'tog-watchdeletion'           => 'Tinyé ihü m na kàcha na ndetu ihe m ne lé',
'tog-minordefault'            => 'Me ka nhoro da na orü ntakịrị níle',
'tog-previewontop'            => 'Zitú ntàkịrị mgbe opuzọr zi igbe orü',
'tog-previewonfirst'          => 'Zitú nke takírí orü mbu',
'tog-nocache'                 => 'Bì-chi cache na otúzọr intaneti gi',
'tog-enotifwatchlistpages'    => 'Türüm e-mail mgbe ihü nor na ndetu ihem ne lé gbanwere',
'tog-enotifusertalkpages'     => 'Türüm e-mail ngbe ébé okwu ndi na banife nkem gbanwere',
'tog-enotifminoredits'        => 'Türüm e-mail maka orü ntakịrị ihüá',
'tog-enotifrevealaddr'        => 'Zifór áhàebeíbị e-mail m na e-mail okwuókà',
'tog-shownumberswatching'     => 'Zi onuogụgụ ndi na banife nke ne lé',
'tog-oldsig'                  => 'Létu ntakiri ndẹlu ejị a ma gí:',
'tog-fancysig'                => 'Mesò ka nkábi nwéré édé wiki (nké énwéghị jikodo nke nọr na onwe)',
'tog-externaleditor'          => 'Jí irü èzí nà áká (màkà ndi òkà nání, ȯ chọrọ ndósé nke kárí na nsónùsòrò gi)',
'tog-externaldiff'            => 'Jí nkéichè èzí nà áká (màkà ndi òkà nání, ȯ chọrọ ndósé nke kárí na nsónùsòrò gi)',
'tog-showjumplinks'           => 'Kwé ka njikodo "mani énū" I mé',
'tog-uselivepreview'          => 'Jí nlé ntàkírí dí ndụ (Í gí nwé JavaScript) (mmètú kanyí lé)',
'tog-forceeditsummary'        => 'Gwam mgbè okwu nsem màkà orüm rürü a díghị',
'tog-watchlisthideown'        => 'Zonari orüm fwuör ndetu ihem ne lé',
'tog-watchlisthidebots'       => 'Zonari orü bot fwuör ndetu ihem ne lé',
'tog-watchlisthideminor'      => 'Zonari orü ntakịrị fwuör ndetu ihem ne lé',
'tog-watchlisthideliu'        => 'Zonari orü ndi na banife nke ndi banyèrè a banyé, fwuör ndetu ihem ne lé',
'tog-watchlisthideanons'      => 'Zonari orü ndi na banife nke ndi ámághị, fwuör ndetu ihem ne lé',
'tog-watchlisthidepatrolled'  => 'Zonari orü ha nè léfù ányá fwuör ndetu ihem ne lé',
'tog-ccmeonemails'            => 'Sipu iye e-mail m na sipu ndi ozor',
'tog-diffonly'                => 'É zìkwàlà ihe nọr na ihü di okpúrù íchiè',
'tog-showhiddencats'          => 'Zi ébéonọr zonari a zonari',
'tog-norollbackdiff'          => 'Kwà diff mgbe byárá na mgbe láázú mèchàrà',

'underline-always'  => 'Ngbẹowula',
'underline-never'   => 'Anáobulạ',
'underline-default' => 'Ndatụ ihü njikota',

# Font style option in Special:Preferences
'editfont-style'     => 'Rüwa ámá udị mkpúrù èdè:',
'editfont-default'   => 'Ndatụ ihü njikota',
'editfont-monospace' => 'Otụ ihe ná kechí mkpúrù èdè',
'editfont-sansserif' => 'Mkpúrù èdè sans-serif',
'editfont-serif'     => 'Mkpúrù èdè Serif',

# Dates
'sunday'        => 'Sondè',
'monday'        => 'Mondè',
'tuesday'       => 'Tusdè',
'wednesday'     => 'Wensdè',
'thursday'      => 'Torsdè',
'friday'        => 'Fridè',
'saturday'      => 'Satorde',
'sun'           => 'Son',
'mon'           => 'Mon',
'tue'           => 'Tus',
'wed'           => 'Wen',
'thu'           => 'Tor',
'fri'           => 'Fri',
'sat'           => 'Sat',
'january'       => 'Önwa Mbú',
'february'      => 'Önwa Abụọ',
'march'         => 'Önwa Atọ',
'april'         => 'Önwa Anọ',
'may_long'      => 'Önwa Ise',
'june'          => 'Önwa Isii',
'july'          => 'Önwa Asaa',
'august'        => 'Önwa Asáto',
'september'     => 'Önwa Itolu',
'october'       => 'Önwa Iri',
'november'      => 'Önwa Iri na otu',
'december'      => 'Önwa Iri na abụọ',
'january-gen'   => 'Önwa Mbú',
'february-gen'  => 'Önwa Abụọ',
'march-gen'     => 'Önwa Atọ',
'april-gen'     => 'Önwa Anọ',
'may-gen'       => 'Önwa Ise',
'june-gen'      => 'Önwa Isii',
'july-gen'      => 'Önwa Asaa',
'august-gen'    => 'Önwa Asatọ',
'september-gen' => 'Önwa Itolu',
'october-gen'   => 'Önwa Iri',
'november-gen'  => 'Önwa Iri na otu',
'december-gen'  => 'Önwa Iri na abụọ',
'jan'           => 'ÖMbú',
'feb'           => 'ÖAbụ',
'mar'           => 'ÖAtọ',
'apr'           => 'ÖAnọ',
'may'           => 'ÖIse',
'jun'           => 'ÖIsi',
'jul'           => 'ÖAsa',
'aug'           => 'ÖAsọ',
'sep'           => 'ÖIto',
'oct'           => 'ÖIri',
'nov'           => 'ÖIrinotu',
'dec'           => 'ÖIrinabụọ',

# Categories related messages
'pagecategories'                 => '{{PLURAL:$1|Ébéonọr|Ébéonọr}}',
'category_header'                => 'Ihü nọr ime ébéonọr "$1"',
'subcategories'                  => 'Ébéonọr ime ime',
'category-media-header'          => 'Nka nọr ime ébéonọr "$1"',
'category-empty'                 => '"Ébéonọr nke enwéghị ihü ma nkà ímé ya."',
'hidden-categories'              => '{{PLURAL:$1|Ébéonọr zonari|Ébéonọr zonari}}',
'hidden-category-category'       => 'Ébéanọr zonari a zonari',
'category-subcat-count'          => '{{PLURAL:$2|Ébéanọr nka nwerechạ ébéanọr-ime nkeá.|Ébéanọr nka nwere {{PLURAL:$1|ébéanọr-ime|$1 ébéanọr-ime}}, guru nke $2 total.}}',
'category-subcat-count-limited'  => 'Ébéonọr nke á nwèrè {{PLURAL:$1|íméébéanọr|íméébéanọr $1}} nke á.',
'category-article-count'         => '{{PLURAL:$2|Ébéonọr nke nwèrè náni ihü nke.|Nke {{PLURAL:$1|ihü nke|$1 ihü ndi a}} nọr na ébéonọr nke a, shí haníle dí $2.}}',
'category-article-count-limited' => 'Nkeá {{PLURAL:$1|ihü dị|ihü $1 dị}} na ébéanọr nkeá.',
'category-file-count'            => '{{PLURAL:$2|Ébéonọr nka nwèrè náni usòrò nka.|{{PLURAL:$1|Usòrò nka|Usòrò nke $1}} di na ímé ébéonọr nga, shí háníle di $2.}}',
'category-file-count-limited'    => 'Nkeá {{PLURAL:$1|usòrò dị|usòrò $1 dị}} na ébéanọr nkeá.',
'listingcontinuesabbrev'         => 'mewá.',
'index-category'                 => 'Ẹdẹle Ihü',
'noindex-category'               => 'Ihü ẹdẹlebu',
'broken-file-category'           => 'Ihü nwere jkọdọ na ga fail gbajírí',

'about'         => 'Màkà',
'article'       => 'Ihü ihe dị',
'newwindow'     => '(o na mepo na onyonyo ohúrù)',
'cancel'        => 'Kàchá',
'moredotdotdot' => 'Ozókwá...',
'mypage'        => 'Ihü',
'mytalk'        => 'Okwu',
'anontalk'      => 'Owu màkà IP nká',
'navigation'    => 'Otú Uzọr',
'and'           => '&#32;ná',

# Cologne Blue skin
'qbfind'         => 'Tüo',
'qbbrowse'       => 'Garia',
'qbedit'         => 'Mèzi',
'qbpageoptions'  => 'Ihü nka',
'qbpageinfo'     => 'Abwátà nka',
'qbmyoptions'    => 'Ihüm',
'qbspecialpages' => 'Ihü mkpà',
'faq'            => 'FAQ',
'faqpage'        => 'Project:FAQ',

# Vector skin
'vector-action-addsection'       => 'Tinyé Okwu',
'vector-action-delete'           => 'Kàcha',
'vector-action-move'             => 'Páfụ',
'vector-action-protect'          => 'Cẹdolu',
'vector-action-undelete'         => 'Á gbàkashikwà',
'vector-action-unprotect'        => 'Nchẹdo mgbanwe',
'vector-simplesearch-preference' => 'Kwe okwu ụmá nchöwa di (akpụkpọ Vector náni)',
'vector-view-create'             => 'Ké',
'vector-view-edit'               => 'Mèzi',
'vector-view-history'            => 'Zí ịta',
'vector-view-view'               => 'Gụ́',
'vector-view-viewsource'         => 'Zi mkpurụ',
'actions'                        => 'Mmèmé',
'namespaces'                     => 'Ámááhà',
'variants'                       => 'Nke ichè ichè',

'errorpagetitle'    => 'Nsogbú',
'returnto'          => 'Ganata na $1.',
'tagline'           => 'Oshị {{SITENAME}}',
'help'              => 'Inyeáká',
'search'            => 'Chọwa',
'searchbutton'      => 'Chọwa',
'go'                => 'Gá',
'searcharticle'     => 'Gá',
'history'           => 'Ịta ihüá',
'history_short'     => 'Ịta',
'updatedmarker'     => 'ihe gáráníru ké mgbe m byàrà nga mbu',
'printableversion'  => 'Nkè I nweríkí dotié',
'permalink'         => 'Jikodo ekechịrị',
'print'             => 'Dotié',
'view'              => 'Lèzí',
'edit'              => 'Mèzi',
'create'            => 'Ké',
'editthispage'      => 'Rüwa na ihü nka',
'create-this-page'  => 'Ké ihü nka',
'delete'            => 'Kàcha',
'deletethispage'    => 'Kàcha ihü nkea',
'undelete_short'    => 'A gbakashikwala {{PLURAL:$1|orü otù|$1 orü}}',
'viewdeleted_short' => 'Zi {{PLURAL:$1|orü otụ bakashịrị|orü $1 bakashịrị}}',
'protect'           => 'Cẹdolu',
'protect_change'    => 'gbanwe',
'protectthispage'   => 'Cẹdolu ihü nka',
'unprotect'         => 'Nchẹdo mgbanwe',
'unprotectthispage' => 'Nchẹdo mgbanwe ihü nka',
'newpage'           => 'Ihü ohúrù',
'talkpage'          => 'Kuwa akíkó maka ihüá',
'talkpagelinktext'  => 'Okwu',
'specialpage'       => 'Ihü mkpà',
'personaltools'     => 'Ngwa nkem',
'postcomment'       => 'Nkeji ohúrù',
'articlepage'       => 'Zi ihü iheníle',
'talk'              => 'Akíkó',
'views'             => 'Há hụrụ ya olé',
'toolbox'           => 'Ngwa Oru',
'userpage'          => "Zi ihü ọ'bànifé",
'projectpage'       => 'Zi ihü orü',
'imagepage'         => 'Zi ihü usòrò',
'mediawikipage'     => 'Zi ihü ozi',
'templatepage'      => 'Zi ihü nkpurụ ihü',
'viewhelppage'      => 'Zi ihü I nye áká',
'categorypage'      => 'Zi ébé ihü nọr',
'viewtalkpage'      => 'Zi akíkó',
'otherlanguages'    => 'Na asụsụ ndị ozó',
'redirectedfrom'    => '(Kufùrù shi $1)',
'redirectpagesub'   => 'Kufù ebe ihü nka na ga',
'lastmodifiedat'    => 'Há rüchàrà na ihü nka na $1, mgbe $2',
'viewcount'         => 'Ha banyere ihü nka na {{PLURAL:$1|otu|$1 mgbe ole}}.',
'protectedpage'     => 'Ihü a cẹdolu a cẹdo',
'jumpto'            => 'Wuá ébé:',
'jumptonavigation'  => 'otú uzọr',
'jumptosearch'      => 'chọwa',
'view-pool-error'   => 'Ndó, ihe na enye juchàrà ejucha oge nka.
Madu kachạrạ ndi choro ihu ihü nka.
Biko chetukwa oge kà oruo mgbe I choro I banyé ihü nka ozor.

$1',
'pool-timeout'      => 'Ógè e zuole Í ché ncedọ',
'pool-queuefull'    => 'Pool kyu zùrù',
'pool-errorunknown' => 'Nsogbu nke námaghi',

# All link text and link target definitions of links into project namespace that get used by other message strings, with the exception of user group pages (see grouppage) and the disambiguation template definition (see disambiguations).
'aboutsite'            => 'Maka {{SITENAME}}',
'aboutpage'            => 'Project:Ihe owù',
'copyright'            => 'Ihe di ime nọr okpúrụ $1',
'copyrightpage'        => '{{ns:project}}:Iwu maka ijë ihe',
'currentevents'        => 'Ihe ne me ubuwá',
'currentevents-url'    => 'Project:I ne me ubüwá',
'disclaimers'          => 'Ihe anyí chọrọ ki ma',
'disclaimerpage'       => 'Project:Ihe I kweshiri ma',
'edithelp'             => 'Inyetuáká I rüwa',
'edithelppage'         => 'Help: I rüwa',
'helppage'             => 'Help: Ihe di ime',
'mainpage'             => 'Ihü Mbu',
'mainpage-description' => 'Ihü Mbu',
'policy-url'           => 'Project:Iwu',
'portal'               => 'Ogbako ọtú',
'portal-url'           => 'Project:Ogbako Ọtú',
'privacy'              => 'Iwu maka ndi ichi ichie',
'privacypage'          => 'Project:Iwu maka ndi ichi ichie',

'badaccess'        => 'Nsogbu ébé ha na nyé ike I bàtá',
'badaccess-group0' => 'I nwéghị ọdà Í kpárá ihe Í chọrí mė.',
'badaccess-groups' => "Ihe Í chọrí me bu ihe ndi ọ'bànifé nke ntàkírí nọr na {{PLURAL:$2|the group|ótù ọtú}} ne me náni: $1",

'versionrequired'     => 'MediaWiki nke $1 gi nọkwạ',
'versionrequiredtext' => 'Ụdì $1 nke MediaWiki gi dị ma Í chȯrí ji ihüá.
Lé [[Special:Version|ụdì ihü]].',

'ok'                      => 'Ngwanu',
'retrievedfrom'           => "Wefụtàrà ya shí ''$1''",
'youhavenewmessages'      => 'I nwèrè $1 ($2).',
'newmessageslink'         => 'Ozi ohúrù',
'newmessagesdifflink'     => 'mkpete azu ihe gbanwere',
'youhavenewmessagesmulti' => 'Inwere eziohu na $1',
'editsection'             => 'mèzi',
'editold'                 => 'mèzi',
'viewsourceold'           => 'zi mkpurụ',
'editlink'                => 'mèzi',
'viewsourcelink'          => 'zi mkpurụ',
'editsectionhint'         => 'Rüwa na élu nkeji: $1',
'toc'                     => 'Ihe dị ime',
'showtoc'                 => 'zi',
'hidetoc'                 => 'zonari',
'collapsible-collapse'    => 'Zekpùdo',
'collapsible-expand'      => 'Gbásà',
'thisisdeleted'           => 'Lé ma tinyechárá $1?',
'viewdeleted'             => 'Lé $1?',
'restorelink'             => '{{PLURAL:$1|orü otụ bakashịrị|orü $1 bakashịrị}}',
'feedlinks'               => 'Bwa ume:',
'feed-invalid'            => 'Nke ntá nzèlè adíghì.',
'feed-unavailable'        => 'Ntáwá ụkọ àdíghị',
'site-rss-feed'           => '$1 ntabì RSS',
'site-atom-feed'          => '$1 ntabì Atom',
'page-rss-feed'           => "''$1'' ntabì RSS",
'page-atom-feed'          => "''$1'' ntabì Atom",
'red-link-title'          => '$1 (ihü a di gì)',
'sort-descending'         => 'Dozi shí àlà',
'sort-ascending'          => 'Dozi shí élú',

# Short words for each namespace, by default used in the namespace tab in monobook
'nstab-main'      => 'Ihü',
'nstab-user'      => "Ihü ọ'bànifé",
'nstab-media'     => 'Ihü nkà',
'nstab-special'   => 'Ihü mkpà',
'nstab-project'   => 'Ihü orürü',
'nstab-image'     => 'Usòrò',
'nstab-mediawiki' => 'Ozi',
'nstab-template'  => 'Àtụ',
'nstab-help'      => 'Ihü ebe ha na nye áká',
'nstab-category'  => 'Ébéonọr',

# Main script and global functions
'nosuchaction'      => 'Mmèmé adighi',
'nosuchactiontext'  => 'Ihe URL chọrọ Í me àdíghị ézíbóté.
Í nwèríkí dèfié URL è dèfie, ma ó nwèríkí bụ nà Í sọrọ jikodo nke àdíghị mma.
Ihe a nwèríkí bu ihe ne zi bug di na ngwa nsónùsòrò nke {{SITENAME}} jì à rü.',
'nosuchspecialpage' => 'Ihü mkpà nka a nogị',
'nospecialpagetext' => '<strong>Í chọrọ ihü mkpà nke à díghị ézíbóté.</strong>

Ndetu màkà ihü mkpà nke à díghị ézíbóté nọ nà [[Special:SpecialPages|{{int:specialpages}}]].',

# General errors
'error'                => 'Nsogbú',
'databaseerror'        => 'Nsogbu nọr na njikota ómárí',
'laggedslavemode'      => "'''Gé ntị:''' Ihüá nwèríkí bu na o nwéghị ihe gáránirú na ógè nso.",
'readonly'             => 'Njikota ómárí gbachịrị',
'missing-article'      => 'Njidé uche nsónùsòrò ènwéghịki tuó mkpụrụ edemede nke ihü nke áhù o kwèshírí hü, nke ha gùrù "$1" $2.

Ihe méré na mgbe ndiá bu ihe diff dáfùrù na ógè ndụ ya ma jikodo ákíkó mbu nke ótù ihü à gbákáshíálá.

Ó bú nà ọ búghị ihe mèrè, ȯ nwèríkí bu Í gbákọtàrà àkà na áká nsónùsòrò.
Biko chi ihe á na áká [[Special:ListUsers/sysop|onye íshí]], dètú URL.',
'missingarticle-rev'   => '(nlèwáriá#: $1)',
'missingarticle-diff'  => '(Íchè: $1, $2)',
'internalerror'        => 'Nsogbu ime ime',
'internalerror_info'   => 'Nsogbu ime ime: $1',
'fileappenderrorread'  => 'Ènwéghíkí gú "$1" mgbe ọ nè tinyé tu ihe.',
'fileappenderror'      => 'Enwerịkị tinyé "$1" gá "$2".',
'filecopyerror'        => 'enwerịkị jë usòrò "$1" ko bu "$2".',
'filerenameerror'      => 'Enwerịkị guwaria áhạ usòrò "$1" ko bu "$2".',
'filedeleteerror'      => "Enwerịkị kàchafu usòrò ''$1''.",
'directorycreateerror' => "Enwerịkị ké usoro ''$1''.",
'filenotfound'         => "Enwerịkị tü usòrò ''$1''.",
'fileexistserror'      => 'Ènwéghịkị dé nà usòrò "$1": ùsòrò nọ',
'unexpected'           => "Onuogụgụ amághị o ga fụtá: ''$1''=''$2''.",
'formerror'            => 'Nsogbu di: a nwere I ki nyefwuör edemede nka',
'badarticleerror'      => 'Áká nke ènwèghịkị mẹ nà ihü nke.',
'badtitle'             => 'Ishi edemede öjö',
'badtitletext'         => 'Íshí ihü Í chọrọ à díghị ézíbóté, efù, mà ȯ dị jikodo di jikodo nke ojö na nke íshí asụsụ-mmékotárí ma wiki-mmékotárí.
O nwèríkí nwé édé ótù ma nke ozor nke ékwéghị na íshí ihü.',
'perfcached'           => 'Ómárí á kachẹrẹ na o nwẹrẹ ki a kugwaghị ya na ogẹ di nso. A maximum of {{PLURAL:$1|one result is|$1 results are}} available in the cache.',
'wrong_wfQuery_params' => 'Okè nke défiere gá Ájújúwf()<br />
Orürü: $1<br />
Ájújú: $2',
'viewsource'           => 'Zi mkpurụ',
'actionthrottled'      => 'Mmèmé a puziélé',
'protectedpagetext'    => 'Ihüá cedolụ maka orürü ạ gáa bá.',
'viewsourcetext'       => 'Í nwèríkí lé na Í jé mkpurụ ihüá:',
'protectedinterface'   => 'Ihü nè nyé édé nke mkpátá màkà ngwa nsónùsòrò, na ó cẹdolu gbò mmelụ.',
'editinginterface'     => "'''Okwu egú:''' I na rü ihü né nyé ihu maka mkpurụ edemede nke eji-a-rü nka.
Gbanwere më ihüa ga mètú ihu élélé nke onye-na-banife maka ndi ozor.
Maka ikuwaria na asụsụ nke ozor, biko chetu I ji [//translatewiki.net/wiki/Main_Page?setlang=ig translatewiki.net], ihe orü MediaWiki di na ama ama.",
'sqlhidden'            => '(nchowa SQL zonari a zonari)',
'namespaceprotected'   => "I weghị ike I rüwa élu ihü nor na '''$1''' áháama.",
'ns-specialprotected'  => 'Ihü mkpà, a nweriki ru na ya.',

# Virus scanner
'virus-badscanner'     => "Ndose ojọ: amaghị ólélé obubu onyá: ''$1''",
'virus-scanfailed'     => 'ojëjë orunotụ dàrà (edemede $1)',
'virus-unknownscanner' => 'amaghị obubu onyá:',

# Login and logout pages
'logouttext'              => "'''I fwuóla ubwá.'''

I nwèríkí jíwá {{SITENAME}} na nke ẹnwéghi áhà, mànà Í nwèríkí [[Special:UserLogin|bátá òzọr]] na áhà Í shị fwüo ma áhà ozọr.
Màkwá na o dị ihü gi zi kà Í nor kwa ímé, o gi kwüshí mgbe Í sáfùrù cache ihe ishi a gá intanet gi.",
'welcomecreation'         => '== Nnöö, $1! ==
Okíkè buwa gi a guchala.
E chefụkwạlạ I gbanwere [[Special:Preferences|{{SITENAME}} iheichọrọ]].',
'yourname'                => "Áhà ọ'bànifé:",
'yourpassword'            => 'Okwúngáfè:',
'yourpasswordagain'       => 'Detuari mkpurụ okwu ejị a gafẹ:',
'remembermypassword'      => 'Chetá edemede éjim a banyé na orunótuá (nke ukwu nke rürü {{PLURAL:$1|chi|chi}} $1)',
'yourdomainname'          => 'Obí gi:',
'login'                   => 'Banyé',
'nav-login-createaccount' => 'Banyé / ké buwá',
'loginprompt'             => 'Í gi nwé cookies Í chórí bátá {{SITENAME}}.',
'userlogin'               => 'Banyé / ké buwá',
'userloginnocreate'       => 'Banyé',
'logout'                  => 'Fwuör',
'userlogout'              => 'Fwuör',
'notloggedin'             => 'I bátà bò',
'nologin'                 => 'I nwegị buwa? $1.',
'nologinlink'             => 'ké otụ buwa',
'createaccount'           => 'Ké otụ buwa',
'gotaccount'              => 'I nwerecha buwa? $1.',
'gotaccountlink'          => 'Banyé',
'createaccountmail'       => 'na e-mail',
'createaccountreason'     => 'Mgbaghaputa:',
'badretype'               => 'Mkpurụ okwu ejị a gafẹ é jëghị.',
'userexists'              => "Áhè ọ'bànifé tírí di na áká onye ozor.
Bíkó nwèré áhà nke ozor.",
'loginerror'              => 'Nsogbu ngbe I choro I bata',
'createaccounterror'      => 'O nweriki ké buwa: $1',
'noname'                  => 'I nyétubọ áhạ buwa di mkpà.',
'loginsuccesstitle'       => 'I batala nke oma',
'loginsuccess'            => "'''Í bátálá nke ọma na ime {{SITENAME}} na áhà \"\$1\".'''",
'nosuchusershort'         => 'Ọ díghị ọ\'bànifé nwéré áhà nke "$1".
Lèmá òtú Í dèrè ya.',
'nouserspecified'         => 'I kweshiri nyetu áhà gi iji a rüoru.',
'login-userblocked'       => 'Ha gbachịrị onye á ezi. Anaá kweté kör banyé.',
'wrongpassword'           => 'Mkpurụ okwu ejị a gafẹ á dighi nke ómá.
Biko meríáríá ya.',
'wrongpasswordempty'      => 'Mkpurụ okwu ejị a gafẹ á dighi.
Biko meríáríá ya.',
'passwordtooshort'        => 'Okwúngáfè gí nwé mkpụrụ édé na ntà gi rü {{PLURAL:$1|1|$1}}.',
'mailmypassword'          => 'Me e-mail okwúngáfè nke ohúrù',
'passwordremindertitle'   => 'Okwúngáfè nke ohürù màkà {{SITENAME}} nke ógè ntàkírí',
'mailerror'               => 'Nsogbú mẹrẹ mgbe ozi nke chorí gá: $1',
'emailconfirmlink'        => 'Lé ka I hü ma ihià bu ézíbóté e-mail gi',
'accountcreated'          => 'Ndoté è mepólé',
'createaccount-title'     => 'Okìké bùwá màkà {{SITENAME}}',
'usernamehasherror'       => "Áhè ọ'bànifé ènwéghịkị nwé nkárí",
'loginlanguagelabel'      => 'Asụsụ: $1',

# Change password dialog
'resetpass'                 => 'Gbanwe okwu éjị à gáfe',
'resetpass_header'          => 'Gbanwe okwúngáfè nke bùwá',
'oldpassword'               => 'Mkpurụ okwu ejị a gafẹ ochië:',
'newpassword'               => 'Mkpurụ okwu ejị a gafẹ nke ohúrù',
'retypenew'                 => 'Dechákwari mkpurụ okwu ejị a gafẹ nke ohúrù:',
'resetpass_submit'          => 'Bá okwu éjị gáfè na áhà Í bànyè',
'resetpass_success'         => 'Mkpurụ okwu ejị a gafẹ a gbanwere nke oma!
I na á banye...',
'resetpass_forbidden'       => 'Okwu éjị à gáfè enwéghịkị gabnwe',
'resetpass-submit-loggedin' => 'Gbanwe okwu éjị à gáfe',
'resetpass-submit-cancel'   => 'Kàchá',
'resetpass-temp-password'   => 'mkpurụ okwu ejị a gafẹ I gi kushi ngwa ngwa:',

# Special:PasswordReset
'passwordreset'              => 'Nkuwaria okwúngáfè',
'passwordreset-emailelement' => "Áhà Ọ'banife: $1
Passwod nke gi gbanwe: $2",

# Special:ChangeEmail
'changeemail-none'   => '(efù)',
'changeemail-cancel' => 'Kàchá',

# Edit page toolbar
'bold_sample'     => 'Mkpúrù èdè íke',
'bold_tip'        => 'Mkpúrù èdè íke',
'italic_sample'   => 'Mkpurụ okwu sélénsé',
'italic_tip'      => 'Mkpurụ okwu sélénsé',
'link_sample'     => 'Ishi edemede nke jikodo',
'link_tip'        => 'Jikodo nke ímé',
'extlink_sample'  => 'http://www.example.com ishi jikodo',
'extlink_tip'     => 'Jikodo nọr na ẹzí (chètá íshí http://)',
'headline_sample' => 'Ahiri ishi mkpurụ edemede',
'headline_tip'    => 'Larri 2 ishiahiri',
'nowiki_sample'   => 'Tinyé mkụrụ edemede enweghị ihe ọbula na ya ti ya nga',
'nowiki_tip'      => 'É gekwàlà otu wiki shi edé',
'image_tip'       => 'Njikota édé a pọrọgwụla',
'media_tip'       => 'Jikodo usòrò',
'sig_tip'         => 'Nkábị gị nwéré nkábị nke ógè',
'hr_tip'          => 'Áhìrì na ga nà àlà (jí ya nke ntàkírí)',

# Edit pages
'summary'                          => 'Mmẹkụwátá:',
'subject'                          => 'Ihe gbasara/Ishi ahiri',
'minoredit'                        => 'Ihe bu orü ntakírí',
'watchthis'                        => 'Lèwá ihüá',
'savearticle'                      => 'Domá ihüa',
'preview'                          => 'Lètú',
'showpreview'                      => 'Létu ntakìrí',
'showlivepreview'                  => 'Létu ntakìrí otu o dị ubwá',
'showdiff'                         => 'Zi ihe gbanwere',
'anoneditwarning'                  => "'''Kpàchákwá anya:''' Ị bághị bo.
IP gi gí détụ na ákíkó mbu ihü a.",
'missingcommenttext'               => 'Biko tinyé ótù okwu na àlà nga.',
'summary-preview'                  => 'Hutukwá mmẹkotá:',
'subject-preview'                  => 'Ihe gbasara/Ishi ahiri I hütü ntakịrị:',
'blockedtitle'                     => 'Há gbachiri onye á ezí',
'autoblockedtext'                  => 'Há kwàchịrị IP gi màkà ọ\'bànifé nke ozor nè ji ya, nke $1 kwàchịrị.
Mgbághapụtà màkà ihe á bu nke:

:\'\'$2\'\'

* Mbìdó nkwàchì: $8
* Mgbà óka màkà nkwàchị: $6
* Onye ha chọrí kwáchí: $7

Í nwèríkí kpó $1 mà [[{{MediaWiki:Grouppage-sysop}}|ndi íshí]] nke ozor ma ọ bu Í chȯrí kpa okwu maka nkwàchi nke ā.

Lè mákwá na Ì gágị jí "me ọ\'bànifé nkeá e-mail", mà Í  nwéré e-mail di ézíbóté di na [[Special:Preferences|òtù ọ\'bànifé ne dósé ihe]] na ha kwáchịghị ya, Í nwèríkí.

IP gi bu $3, na ID nkwàchi bu #$5.
Biko tinyé cha ihe ńdía na ájújú nkeówulà I gi me.',
'blockednoreason'                  => 'amaghi ihe omẹrẹ ya maka',
'whitelistedittext'                => 'Í gi $1 Í rü na ihü.',
'nosuchsectiontitle'               => 'Aná a hu nkeji',
'loginreqtitle'                    => 'I kweshiri banyé eba',
'loginreqlink'                     => 'Banyé',
'loginreqpagetext'                 => 'I keshiri $1 I cho ki hü ihü ndi ozor.',
'accmailtitle'                     => 'mkpurụ okwu ejị a gafẹ a sipuole.',
'newarticle'                       => '(Nke ohúrù)',
'newarticletext'                   => "Í sòrò jikodo na ihü nke adíghị bòdì.
Í chȯrí ké ihü nke áhù, bìdó Í pị áka nà igbé nȯr nà àlà ngá (lé [[{{MediaWiki:Helppage}}|ihü nkwádo]] màkà ụmà ozor).
Ȯ bú nà Í byàrà ngá na aghọ, piá mpiá otúzor-intanet gi nke '''àzú'''.",
'noarticletext'                    => 'Mkpụrụ edemede à díghị na ihü nke.
Í nwèríkí [[Special:Search/{{PAGENAME}}|tuó íshí ihü nke á]] na ihü ndi ozor,
<span class="plainlinks">[{{fullurl:{{#Special:Log}}|page={{FULLPAGENAMEE}}}} chọwa na ndetu nchètá di nwanne],
mà [{{fullurl:{{FULLPAGENAME}}|action=edit}} Í nwèríkí rü nà ihü á]</span>.',
'userpage-userdoesnotexist-view'   => 'Bùwá ọ\'bànifé "$1 à díghị na nsónùsòrò.',
'blocked-notice-logextract'        => "Ha gbàchìrì ọ'bànifé nke.
Ndetu nchèta mbgàchì ǹkè ógè nso di na àlà màkà ádià má àmá:",
'usercssyoucanpreview'             => "'''Lè kwá:''' Jí mpiá \"{{int:showpreview}}\" Í létú òtù CSS gí di mgbe Í donyèrè ya.",
'userjsyoucanpreview'              => "'''Lè kwá:''' Jí mpiá \"{{int:showpreview}}\" Í létú òtù JavaScript gí di mgbe Í donyèrè ya.",
'updated'                          => '(Kuwariala)',
'note'                             => "'''Ndetụrụ:'''",
'previewnote'                      => "'''Chètá na iheá bu ńlé náni.'''
Ihe Í gbànwèrè e donyè bòdì!",
'editing'                          => 'I rüwa $1',
'editingsection'                   => 'I rüwa $1 (nkeji)',
'editingcomment'                   => 'I rüwa $1 (nkeji ohúrù)',
'editconflict'                     => 'Orü ná lüogù: $1',
'yourtext'                         => 'Mkpurụ edemede gi',
'storedversion'                    => 'Ihe gbanwere nke dosèrè a dose',
'yourdiff'                         => 'Ihedichiè',
'copyrightwarning'                 => "Biko gè kwá na orü nílw gárá {{SITENAME}} di na nchétá na ȯ nà gá na okpúrù $2 (lé $1 màkà okwu ozor).
Ó bú nà Ì chóghị ka ihe Í dèrè Í gi di nà áká ndi ozor Í ghi rübwó ya na Í gi gbásà ya na mgbe há chọrọ, é tìkwàrà ya nga.<br />
Í nà me nkwà ányị na Í dèrè ihe á na onwe gi, ma Í dépùtàrà ya shí ihe akwukwo nọr na ámá owere ma ihe owere ozor.
'''É nyè kwàrà ihe íwú kèchịrị na mgbe Ì nwéghị òdạ!'''",
'semiprotectedpagewarning'         => "'''Lè kwá:''' Ha gbachịrị Ihü nke ka nání ndi íshí bu ndi nwéríkí rü na élú ya.
Ndetu banyéré nkè ogẹ nso di na okpúrụ màkà ádịamámá:",
'templatesused'                    => '{{PLURAL:$1|Àtụ|Àtụ}} hé jịrị rü ihüá:',
'templatesusedpreview'             => '{{PLURAL:$1|Àtụ|Àtụ}} hé jịrị na nlétú nke:',
'templatesusedsection'             => '{{PLURAL:$1|Àtụ|Àtụ}} hé jịrị na nkeji nke:',
'template-protected'               => '(cẹdoluecẹdo)',
'template-semiprotected'           => '(cẹdolu-ntakiri)',
'hiddencategories'                 => 'Ihü a dị nà nke ótù {{PLURAL:$1|ébéonọr zọnàrì nke 1|ébéonọr zọnàrì nke $1}}:',
'nocreatetitle'                    => 'Í ké ihü nwèrè ùbe',
'nocreate-loggedin'                => 'Í nwéghi ọdà Í ké ihü ohụrụ.',
'permissionserrors'                => 'Nsobgu na ỏdà',
'permissionserrorstext-withaction' => 'Í nwéghi ọdà Í $2, {{PLURAL:$1|màkà|màkà}} ihe ha detùrù na àlà nga:',
'log-fulllog'                      => 'Zìchá ndétu ncheta',
'edit-conflict'                    => 'Orü ná lüogù.',
'edit-no-change'                   => 'Ha túfùghị orü gi ónú, màkà ọ díghì ihe gbanwere na edemede.',
'edit-already-exists'              => 'Ènwéghịkị ké ihü nke ọhúrù.
Ọ di kwa.',

# Parser/template warnings
'parser-template-loop-warning' => 'Etemete àtụ dị: [[$1]]',

# "Undo" feature
'undo-summary' => 'Emekwàlà orübà $1 shí [[Special:Contributions/$2|$2]] ([[User talk:$2|talk]])',

# Account creation failure
'cantcreateaccounttitle' => 'Enwéghịkị ke buwá',

# History pages
'viewpagelogs'           => 'Zi ndetu ncheta màkà ihü a',
'nohistory'              => 'Ákíkó mbu màkà orü àdíghị màkà ihüá.',
'currentrev'             => 'Kuwaria nke ubüwạ',
'currentrev-asof'        => 'Kuwaria shi mgbe $1',
'revisionasof'           => 'Orübà nà ógè $1',
'revision-info'          => 'Orübà na nke $1 shí $2',
'previousrevision'       => 'Orübà di kwa nke ichié',
'nextrevision'           => 'Orübà di kwa ohúrù →',
'currentrevisionlink'    => 'Orübà nke ubwa',
'cur'                    => 'nke I nor',
'next'                   => 'na nke ozor',
'last'                   => 'nke gafèrè',
'page_first'             => 'nke buzọr',
'page_last'              => 'nke lara azu',
'histlegend'             => "Mkpátá íche: ká igbé radio nke orüma Í lèmá otụ hámá abụọ ditù nà Í gi tié mkpátá bànyé nà àlà.<br />
Okwu ụmà: '''({{int:cur}})''' = gbánwe na nké orü mbu, '''({{int:last}})''' = ihe íchè na nké orü di gbárá mbu, '''{{int:minoreditletter}}''' = orü ntà.",
'history-fieldset-title' => 'Akíkó mbu maka a garacha I garachara',
'history-show-deleted'   => 'Nani nke gbakashiala',
'histfirst'              => 'Nke buzọr',
'histlast'               => 'Nke ohúrù',
'historysize'            => '({{PLURAL:$1|byte 1|byte $1 di}})',
'historyempty'           => '(kwapụrụ)',

# Revision feed
'history-feed-title'          => 'Akíkó mbu maka elélé orü',
'history-feed-description'    => 'Ákíkó mbu màkà orübà nke ihüá na wiki',
'history-feed-item-nocomment' => '$1 ngbe $2',

# Revision deletion
'rev-deleted-comment'        => '(okwu e wefụolé)',
'rev-deleted-user'           => '(áhá onye na ké a wefụolé)',
'rev-delundel'               => 'zi/zonari',
'rev-showdeleted'            => 'zi',
'revdelete-show-file-submit' => 'Eeh',
'revdelete-hide-text'        => 'Zonari mkpụrụ edemede nke orübà',
'revdelete-hide-image'       => 'Zonari ihe no ime usòrò',
'revdelete-hide-name'        => 'Zonari mmèmé na ntido',
'revdelete-hide-comment'     => 'Zonari ihe okwu orü',
'revdelete-hide-user'        => "Zonari áhà ọ'bànifé nke onye na rü/áhàebeíbị IP ya",
'revdelete-radio-same'       => '(e mesukwàlà)',
'revdelete-radio-set'        => 'Eeh',
'revdelete-radio-unset'      => 'Mbà',
'revdelete-log'              => 'Mgbághapụtà:',
'revdel-restore'             => 'gbanwe ọtù ọ gị zí',
'revdel-restore-deleted'     => 'orürü gbakashịrị',
'pagehist'                   => 'Ịta ihüá',
'deletedhist'                => 'Ákíkó mbu bakashịrị',
'revdelete-reasonotherlist'  => 'Mgbághàpụtá ozor',
'revdelete-edit-reasonlist'  => 'Rüwa mgbághapụtà nkàchafu',
'revdelete-offender'         => 'Ọde akwukwo nke orübà:',

# History merging
'mergehistory'                => 'Tìkȯtá ákíkó mbu nke ihü ndiá',
'mergehistory-from'           => 'Ihü mkpòlógwụ:',
'mergehistory-into'           => 'Ihü ȯ na gá:',
'mergehistory-submit'         => 'Tìkótá orürü',
'mergehistory-empty'          => 'Ọ díghị orübà nwéríkí tíkȯtá.',
'mergehistory-no-source'      => 'Mkpọlógwù ihü $1 nóghị.',
'mergehistory-no-destination' => 'Nnákpu ihü $1 nóghị.',
'mergehistory-autocomment'    => 'Tìkọtàrà [[:$1]] ga na ímé [[:$2]]',
'mergehistory-comment'        => 'Tìkọtàrà [[:$1]] ga na ímé [[:$2]]: $3',
'mergehistory-reason'         => 'Mgbághapụtà:',

# Merge log
'mergelog'           => 'Tìkȯtá ndétu-nchèta',
'pagemerge-logentry' => 'tìkọtàrà [[$1]] ga na ímé [[$2]] (orübà rúrú $3)',
'revertmerge'        => 'Emẹkotala',

# Diffs
'history-title'           => 'Ákíkó mbu màkà orü nọr na élú "$1"',
'difference'              => '(Ihe dị íche na orü ndi á)',
'lineno'                  => 'Ahiri $1:',
'compareselectedversions' => 'Sikwụ orü áká dị',
'editundo'                => 'mẹ̀rí àzụ́',

# Search results
'searchresults'                    => 'Ndọfùtà nchọwa',
'searchresults-title'              => "Ihe futárá nchowá màkà ''$1''",
'searchresulttext'                 => 'Màkà okwu nke ozor básárá í tu {{SITENAME}}, lé [[{{MediaWiki:Helppage}}|{{int:help}}]].',
'searchsubtitle'                   => 'Í tụrụ \'\'\'[[:$1]]\'\'\' ([[Special:Prefixindex/$1|ihü nílé bidóró "$1"]] {{int:pipe-separator}} [[Special:WhatLinksHere/$1|ihü nílé na gá "$1"]])',
'searchsubtitleinvalid'            => "Í tùrù '''$1'''",
'titlematches'                     => 'Íshí ihü dàbànyèrè',
'notitlematches'                   => 'Ọ díghì íshí ihü dí kà nke á hù',
'textmatches'                      => 'Mkpụrụ édémédé nwèrè ihü ȯ dị na',
'notextmatches'                    => 'Mkpụrụ édémédé enwéghị ihü ȯ dị na',
'prevn'                            => '{{PLURAL:$1|$1}} nke àzú',
'nextn'                            => '{{PLURAL:$1|$1}} nke ozor',
'prevn-title'                      => '{{PLURAL:$1|Ihe fútárá|Ihe fútárá}} nke àzú nke $1',
'nextn-title'                      => '{{PLURAL:$1|Ihe fútárá|Ihe fútárá}} nke sò nke $1',
'shown-title'                      => 'Zí $1 {{PLURAL:$1|ihe fútárá|ihe fútárá}} na ótù ihü',
'viewprevnext'                     => 'Lé ($1 {{int:pipe-separator}} $2) ($3)',
'searchmenu-legend'                => 'Màkà nchöwa',
'searchmenu-new'                   => "'''Ké ihü \"[[:\$1]]\" na wiki nke á!'''",
'searchhelp-url'                   => 'Help:Ihe di ime',
'searchprofile-articles'           => 'Ihü ihe dị',
'searchprofile-project'            => 'Ihü Nkwádo na Orürü',
'searchprofile-images'             => 'Nkaníle',
'searchprofile-everything'         => 'Iheníle',
'searchprofile-advanced'           => 'Nke kárí',
'searchprofile-articles-tooltip'   => 'Chọwa na $1',
'searchprofile-project-tooltip'    => 'Chọwa na $1',
'searchprofile-images-tooltip'     => 'Chọwa màkà usòrò',
'searchprofile-everything-tooltip' => 'Tùwé ihe nile (na okwu ihü)',
'searchprofile-advanced-tooltip'   => 'Chọwa na ímé áhàámá nke gí Í kèrè',
'search-result-size'               => '$1 ({{PLURAL:$2|mkpurụ edemede 1|$2 mkpurụ edemede}})',
'search-result-score'              => 'Otu o di nkpà: $1%',
'search-redirect'                  => '(kúfù $1)',
'search-section'                   => '(nkeji $1)',
'search-suggest'                   => 'Ị̀ kwèshirí dé: $1',
'search-interwiki-caption'         => 'Orürü nwanne nwanyị',
'search-interwiki-default'         => '$1 nke ziri:',
'search-interwiki-more'            => '(dikarírí)',
'search-mwsuggest-enabled'         => 'ma okwu',
'search-mwsuggest-disabled'        => 'adighi okwu',
'search-relatedarticle'            => 'Nwanne',
'searcheverything-enable'          => 'Chọwa na ébé nílé',
'searchrelated'                    => 'nke kọlu',
'searchall'                        => 'nke níle',
'nonefound'                        => "'''Mà kwá''': Náni áhàama ótù dìkàrì Í tuó ya na áká onwe.
Nwàné ótù okwu íshí na ihe Í nè tú jí ''háníle:'' Í tuó ihe nílé (bu kwá ihü okwu, àtụ, échétá ma échetàghị), ma Í gi ji áhàama Í chọrọ màkà ótù okwu íshí.",
'powersearch'                      => 'Nchöwá nkè íshí',
'powersearch-legend'               => 'Nchöwá nkè íshí',
'powersearch-ns'                   => 'Tuo na ímé:',
'powersearch-redir'                => 'Dètú nkúfù',
'powersearch-field'                => 'Chọwa màkà',
'powersearch-togglelabel'          => 'Lechányá:',
'powersearch-toggleall'            => 'Haníle',
'powersearch-togglenone'           => 'Efù',

# Quickbar
'qbsettings'               => 'Mkpọrọ-ȯsȯ-ọsọ',
'qbsettings-none'          => 'Efù',
'qbsettings-fixedleft'     => 'Gbado na áká èkpè',
'qbsettings-fixedright'    => 'Gbado na áká ìkengà',
'qbsettings-floatingleft'  => 'Ne fé na áká èkpè',
'qbsettings-floatingright' => 'Ne fé na áká nrí',

# Preferences page
'preferences'               => 'Otu ha dosẹrẹ ihe',
'mypreferences'             => 'Otú m shị na dose ihem',
'prefsnologin'              => 'I bátà bò',
'changepassword'            => 'Gbanwe okwu éjị à gáfe',
'prefs-skin'                => 'Akpụkpọ',
'skin-preview'              => 'Lètú',
'datedefault'               => 'Otú é shị na dose ihe efù',
'prefs-datetime'            => 'Ubochi na ogẹ',
'prefs-personal'            => "Nkówá ọ'bànifé",
'prefs-rc'                  => 'Mgbánwè ógè nso',
'prefs-watchlist'           => 'Ndétụnlé',
'prefs-watchlist-days-max'  => 'Maximum $1 {{PLURAL:$1|day|days}}',
'prefs-misc'                => 'Mcheta-ma-mchetaghim',
'prefs-resetpass'           => 'Gbanwe okwu éjị à gáfe',
'prefs-email'               => 'Màkà e-mail',
'prefs-rendering'           => 'Ọdịdị',
'saveprefs'                 => 'Domá',
'prefs-editing'             => 'Írüwa',
'rows'                      => 'Ǹdịlị:',
'columns'                   => 'Ogìdì:',
'searchresultshead'         => 'Chọwa',
'resultsperpage'            => 'Nlé na ihü:',
'stub-threshold-disabled'   => 'Ápụgị òkò',
'timezonelegend'            => 'Nkeji ogẹ:',
'localtime'                 => 'Ogẹ ebeanọr:',
'servertime'                => 'Ógè nsónùsòrò òdìbọ:',
'timezoneregion-africa'     => 'Afrikạ',
'timezoneregion-america'    => 'Amirikạ',
'timezoneregion-antarctica' => 'Antarktikạ',
'timezoneregion-arctic'     => 'Arktik',
'timezoneregion-asia'       => 'Azia',
'timezoneregion-atlantic'   => 'Abwädi Ukwu',
'timezoneregion-australia'  => 'Ostraliya',
'timezoneregion-europe'     => 'Alá Bèke',
'timezoneregion-indian'     => 'Abwädi Ukwu India',
'timezoneregion-pacific'    => 'Òrìmìlì Pasifik',
'prefs-searchoptions'       => 'Màkà nchöwa',
'prefs-namespaces'          => 'Áhàámá',
'default'                   => 'nke éjị bịdó',
'prefs-files'               => 'Usòrò',
'prefs-custom-css'          => 'CSS nà áká mádu',
'prefs-custom-js'           => 'JavaScript na áká mádu',
'youremail'                 => 'E-mail:',
'username'                  => "Áhà ọ'bànifé:",
'uid'                       => "ID ọ'bànifé:",
'prefs-memberingroups'      => 'Onyé otu nke {{PLURAL:$1|ọtú|ọtú}}:',
'yourrealname'              => 'Ézíbóté áhà:',
'yourlanguage'              => 'Ásụ̀sụ̀:',
'yournick'                  => 'Ndè áhà gi òhúrù:',
'yourgender'                => 'Nwayi/okpoho ma o nwoke:',
'gender-unknown'            => 'Ámákwàghị',
'gender-male'               => 'Òkò',
'gender-female'             => 'Ányị̀',
'email'                     => 'ozi e-mail',
'prefs-help-email-required' => 'Áhàebeíbị e-mail gí di.',
'prefs-signature'           => 'Áhà gi',
'prefs-timeoffset'          => 'Nwopù ógè',
'prefs-diffs'               => 'Íchè',

# User rights
'userrights-user-editname' => "Tìnyé áhà ọ'bànifé:",
'editusergroup'            => "Mèzí ọtú nke ọ'bànifé",
'userrights-editusergroup' => "Mèzí ọtú nke ọ'bànifé",
'saveusergroups'           => "Domá ọtú nke ọ'bànifé",
'userrights-groupsmember'  => 'Onye ọtú nke:',
'userrights-reason'        => 'Mgbághapụtà:',

# Groups
'group'            => 'Ọtú:',
'group-user'       => "Ọ'bànifé",
'group-bot'        => 'Bot',
'group-sysop'      => 'Ndi íshí',
'group-bureaucrat' => "Ọdọzị'obodo",
'group-suppress'   => 'Aghọ',
'group-all'        => '(háníle)',

'group-user-member'          => "ọ'bànifé",
'group-autoconfirmed-member' => "ọ'bànifé kwé'nà'áká",
'group-bot-member'           => 'bot',
'group-sysop-member'         => 'onye íshí',
'group-bureaucrat-member'    => "ọdọzị'obodo",
'group-suppress-member'      => 'aghọ',

'grouppage-user'  => "{{ns:project}}:Ọ'bànifé",
'grouppage-bot'   => '{{ns:project}}:Bot',
'grouppage-sysop' => '{{ns:project}}:Ndi Íshí wiki',

# Rights
'right-read'       => 'Gụwá ihü',
'right-edit'       => 'Rüwa ihü',
'right-createpage' => 'Ké ihü (nke nadíghị na ihü okwu)',
'right-move'       => 'Páfù ihü',
'right-movefile'   => 'Páfù usòrò',
'right-upload'     => 'Tịnyé ihe na nsónùsòrò',
'right-delete'     => 'Kàchafu ihü',
'right-bigdelete'  => 'Kàcha ihü nwéré ákíkó mbu dí ógólógó',
'right-undelete'   => 'Ágbakashia ótù ihü',

# User rights log
'rightslog'  => "Ndetu échìchè íwú ọ'bànifé",
'rightsnone' => '(efù)',

# Associated actions - in the sentence "You do not have permission to X"
'action-read'       => 'guwa ihüá',
'action-edit'       => 'rüo élu ihüá',
'action-createpage' => 'ké ihü',
'action-move'       => 'puzié ihü nke',
'action-movefile'   => 'puzié usòrò',
'action-upload'     => 'tinyé njikota èdèa',
'action-reupload'   => 'tinyé ihe ozor élu njikota èdèa',
'action-delete'     => 'kàcha ihü nka',

# Recent changes
'nchanges'                          => '$1 {{PLURAL:$1|gbanwere|gbanwere}}',
'recentchanges'                     => 'Mgbánwè ógè nso',
'recentchanges-legend'              => 'Nràlụ màkà Ihe gbanwere ubwá',
'recentchanges-feed-description'    => 'Chóputà ihe ógẹ ǹsò na wiki ímé órírí nke á.',
'recentchanges-label-minor'         => 'Ihe bu orü ntakírí',
'rcnote'                            => "Na àlà {{PLURAL:$1|bu gbanwere '''1'''|bu gbanwere mgbèdè nke '''$1'''}} na mgbèdè {{PLURAL:$2|chi|chi '''$2'''}}, na mgbe $5, $4.",
'rclistfrom'                        => 'Zìrí ihe gbanwere ọhúrù shí $1',
'rcshowhideminor'                   => 'orü ntákírí $1',
'rcshowhidebots'                    => 'bot $1',
'rcshowhideliu'                     => 'Ndi né ké dị $1 di íme',
'rcshowhideanons'                   => "$1 ndi ọ'bànifé nke amághị",
'rcshowhidepatr'                    => '$1 orü hä lèrè',
'rcshowhidemine'                    => '$1 ihe m rürü',
'rclinks'                           => 'Zí nke mbu $1 gbawere na ubochi gárá nke $2<br />$3',
'diff'                              => 'Íchè',
'hist'                              => 'akíkómbu',
'hide'                              => 'Zonari',
'show'                              => 'Zi',
'minoreditletter'                   => 'm',
'newpageletter'                     => 'N',
'boteditletter'                     => 'b',
'number_of_watching_users_pageview' => "[$1 {{PLURAL:$1|ọ'bànifé|ọ'bànifé}} ne lé anya]",
'rc_categories_any'                 => 'Nkówụlà',
'newsectionsummary'                 => '/* $1 */ nkeji ohúrù',
'rc-enhanced-expand'                => 'Zi ihe di ime (Í gí nwere JavaScript)',
'rc-enhanced-hide'                  => 'Zonari ihe di ime',

# Recent changes linked
'recentchangeslinked'         => 'Gbanwèrè gbásírí ya',
'recentchangeslinked-feed'    => 'Gbanwèrè gbásírí ya',
'recentchangeslinked-toolbox' => 'Gbanwèrè gbásírí ya',
'recentchangeslinked-title'   => 'Gbanwere bu nwanne "$1"',
'recentchangeslinked-summary' => "Ndétu nkeá nwèrè ihe gbanwere na ógè nso nke jikodọrọ ótù ihü (ma nke na ga ọ'bànifé nọr na ótù ébéonọr).
Ihü nọr na [[Special:Watchlist|ndétu ihe Í ne lé]] di na mkpụrụ edemede '''shírí íke'''.",
'recentchangeslinked-page'    => 'Áhà ihü:',
'recentchangeslinked-to'      => 'Zí íhé gbanwéré na ihü jikodòrò ihü nke na ọnọdù',

# Upload
'upload'              => 'Tịnyé ihe na nsónùsòrò',
'uploadbtn'           => 'Tịnyé ihe na nsónùsòrò',
'upload-permitted'    => 'Usòrò hé kwèrè: $1.',
'upload-preferred'    => 'Usòrò há ne tú: $1.',
'upload-prohibited'   => 'Usòrò chȯghị: $1.',
'uploadlog'           => 'ndétu-ncheta ntinyé-na-élú',
'uploadlogpage'       => 'Tìnyé ntinyé na élú',
'filename'            => 'Áhà usòrò',
'filedesc'            => 'Mmẹkụwátá',
'fileuploadsummary'   => 'Mmẹkụwátá:',
'filereuploadsummary' => 'Gbanwere maka usòrò:',
'filesource'          => 'Mkpọlọ́gwụ̀:',
'savefile'            => 'Domá usòrò',
'uploadedimage'       => '"[[$1]]" dị na élú',
'upload-source'       => 'Usòrò mkpọlógwù',
'sourcefilename'      => 'Áhà usòrò mkpọlógwù:',
'sourceurl'           => 'URL mkpọlógwù:',
'upload-description'  => 'Nkówá usòrò',
'watchthisupload'     => 'Lèwá ákwúkwó orunotunị',
'upload-warning-subj' => 'Ndọ ntị màkà ntínyé',

# HTTP errors
'http-read-error' => 'Nsogbu Í gü HTTP.',

# Some likely curl errors. More could be added from <http://curl.haxx.se/libcurl/c/libcurl-errors.html>
'upload-curl-error6' => 'Ènwéghịkị ruó URL',

'license'        => 'Nkwényé:',
'license-header' => 'Nkwényé',
'nolicense'      => 'Ọ dígì nke áká di.',

# Special:ListFiles
'imgfile'               => 'usòrò',
'listfiles'             => 'Ndétu usòrò',
'listfiles_thumb'       => 'Nvọáká',
'listfiles_date'        => 'Ǹgụ́ụ̀bọ̀chị̀',
'listfiles_name'        => 'Áhà',
'listfiles_user'        => "Ọ'bànifé",
'listfiles_size'        => 'Ívụ',
'listfiles_description' => 'Nkówá',
'listfiles_count'       => 'Ùdị',

# File description page
'file-anchor-link'          => 'Usòrò',
'filehist'                  => 'Ịta nke usòrò',
'filehist-help'             => 'Kpàtá na úbochi/ógè Í zí usòrò ọtụ ȯ dị mgbe áhù.',
'filehist-deleteall'        => 'kàcha hanílé',
'filehist-deleteone'        => 'kàcha',
'filehist-revert'           => 'gbanwe lá àzú',
'filehist-current'          => 'nka',
'filehist-datetime'         => 'Afọ/Ogẹ',
'filehist-thumb'            => 'Nvọáká',
'filehist-thumbtext'        => 'NvóÁká màkà otù ȯ dị nà $1',
'filehist-nothumb'          => 'Nvọáká adịghị',
'filehist-user'             => "Ọ'bànifé",
'filehist-dimensions'       => 'Ógólógó na asaá',
'filehist-filesize'         => 'Ívù usòrò',
'filehist-comment'          => 'Okwu-nokwu',
'filehist-missing'          => 'Usòrò è fwuólé',
'imagelinks'                => 'Mgbanwe usòrò',
'linkstoimage'              => '{{PLURAL:$1|Ihü nká|Ihü nke $1}} na jikodo gá usòrò nká:',
'nolinkstoimage'            => 'Àdíghị ihü na jikodo usòrò nke.',
'sharedupload'              => 'Ákwúkwó runotu nke shì $1 na ó nwèríkí di na orürü nke ndi ozor.',
'uploadnewversion-linktext' => 'Tinyé usòrò di òhúrù na élú nke',
'shared-repo-from'          => 'shí $1',

# File reversion
'filerevert'         => 'Gbanwe na àzú $1',
'filerevert-legend'  => 'Lá na àzú usòrò',
'filerevert-comment' => 'Mgbághapụtà:',
'filerevert-submit'  => 'Gbanwe lá àzú',

# File deletion
'filedelete'                  => 'Kàcha $1',
'filedelete-legend'           => 'Kàcha usòrò',
'filedelete-comment'          => 'Mgbághapụtà:',
'filedelete-submit'           => 'Kàcha',
'filedelete-otherreason'      => 'Màkà ihe ozor kwa:',
'filedelete-reason-otherlist' => 'Mgbághàpụtá ozor',

# MIME search
'mimesearch' => 'nchöwa MIME',
'mimetype'   => 'Ùdị MIME:',
'download'   => 'danwèré',

# Unwatched pages
'unwatchedpages' => 'Ihü hanéléghị',

# List redirects
'listredirects' => 'Ndétu nke nkúfù',

# Unused templates
'unusedtemplates'    => 'Àtụ hè jí gị',
'unusedtemplateswlh' => 'jikodo ndi ozor',

# Random page
'randompage' => 'Edemede nkeówúlạ',

# Statistics
'statistics'              => 'Olìlé ọtụ ihe dị',
'statistics-header-pages' => 'Ọmúmú-nà-ńlé ihü',
'statistics-header-edits' => 'Rüwá ọmúmú-nà-ńlé',
'statistics-header-views' => 'Lé ọmúmú-nà-ńlé',
'statistics-header-users' => "Ọmúmú-nà-ńlé nke ọ'bànifé",
'statistics-articles'     => 'Ihü ihe dị',
'statistics-pages'        => 'Ihü',
'statistics-files'        => 'Usòrò hé tinyèrè',
'statistics-views-total'  => 'Há hụrụ ya olé níle',
'statistics-users-active' => "Ọ'bànifé di galagala",

'disambiguationspage' => 'Template:ọlúchịgị',

'double-redirect-fixed-move' => '[[$1]] a puziele.
Ubwa, o na ga [[$2]].',

'brokenredirects'        => 'Nkúfù gbàjịrị',
'brokenredirects-edit'   => 'mèzi',
'brokenredirects-delete' => 'kàcha',

'withoutinterwiki'        => 'Ihü nke enweghi jikodo rúrú asụsụ',
'withoutinterwiki-legend' => 'Na íshí mkpụrụ okwu',
'withoutinterwiki-submit' => 'Zi',

# Miscellaneous special pages
'nbytes'            => '$1 {{PLURAL:$1|byte|byte di}}',
'ncategories'       => '{{PLURAL:$1|ébéonọr|ébéonọr}} $1',
'nlinks'            => '{{PLURAL:$1|jikodo|jikodo}} $1',
'nmembers'          => "{{PLURAL:$1|ọ'bànifé|Ndi n'bànifé}} $1",
'nrevisions'        => '{{PLURAL:$1|orübà|orübà}} $1',
'nviews'            => '{{PLURAL:$1|he lèrè nke|he lèrè nke}} $1',
'lonelypages'       => 'Ihü nke ogbènyè',
'popularpages'      => 'Ihü ne wú',
'wantedpages'       => 'Ihü há chọrọ',
'prefixindex'       => 'Ihü nílé jírí mkpụrụ édémédé nke mbu',
'shortpages'        => 'Ihü mkpümkpü',
'longpages'         => 'Ihü ógólógó',
'protectedtitles'   => 'Íshí édé cẹdolu',
'listusers'         => "Ndetu ọ'bànifé",
'usereditcount'     => '$1 {{PLURAL:$1|rüwá|orürü}}',
'usercreated'       => 'Kéré na $1 mgbe $2',
'newpages'          => 'Ihü ohúrù',
'newpages-username' => "Áhà ọ'bànifé:",
'ancientpages'      => 'Ihü díkárí íchié',
'move'              => 'Páfụ',
'movethispage'      => 'Páfù ihüá',
'notargettitle'     => 'Ntido adighị',
'pager-newer-n'     => '{{PLURAL:$1|1 nke ohúrù|$1 nke ohúrù}}',
'pager-older-n'     => '{{PLURAL:$1|1 nke ichié |$1 nke ichié}}',
'suppress'          => 'Aghọ',

# Book sources
'booksources'               => 'Ébé ákwúkwó shị',
'booksources-search-legend' => 'Tuó íshí akwúkwó shì',
'booksources-go'            => 'Gá',

# Special:Log
'specialloguserlabel'  => "Ọ'bànifé:",
'speciallogtitlelabel' => 'Ishi:',
'log'                  => 'Ndetu-nchétá',

# Special:AllPages
'allpages'          => 'Ihü níle',
'alphaindexline'    => '$1 ruó $2',
'nextpage'          => 'Ihü sò ($1)',
'prevpage'          => 'Ihü nke búzọr ($1)',
'allpagesfrom'      => 'Zi ihü bídóró na:',
'allpagesto'        => 'Zi na ihu ihü ná kwúshí nà:',
'allarticles'       => 'Ihü níle',
'allinnamespace'    => 'Ihü níle (ámááhạ $1)',
'allnotinnamespace' => 'Ihü níle (a noghị ime ámááhạ $1)',
'allpagesprev'      => 'Nke gafèrè',
'allpagesnext'      => 'Nàíhú',
'allpagessubmit'    => 'Gá',

# Special:Categories
'categories' => 'Ébéanọr',

# Special:DeletedContributions
'sp-deletedcontributions-contribs' => 'ihe rürü di mkpa',

# Special:LinkSearch
'linksearch'      => 'Òtú jikodo di èzí',
'linksearch-ns'   => 'Áhàámá:',
'linksearch-ok'   => 'Chọwa',
'linksearch-line' => '$1 jikọdọ shí $2',

# Special:ListUsers
'listusers-submit'   => 'Zi',
'listusers-noresult' => "Ọ hügị ọ'bànifé.",
'listusers-blocked'  => '(kwàchịrị)',

# Special:ActiveUsers
'activeusers-hidebots'   => 'Zonari bot',
'activeusers-hidesysops' => 'Zonari ndi íshí',
'activeusers-noresult'   => "Ọ hügị ọ'bànifé.",

# Special:Log/newusers
'newuserlogpage' => "Ndétu nchétá ihe ọ'bànifé kèrè",

# Special:ListGroupRights
'listgrouprights-group'        => 'Ọtú',
'listgrouprights-rights'       => 'Nkwènyé',
'listgrouprights-members'      => '(ndetu ndi nọr nga)',
'listgrouprights-addgroup'     => 'Gbàkọ {{PLURAL:$2|ọtú|ọtú}}: $1',
'listgrouprights-addgroup-all' => 'Tìnyé ọtú nílé',

# Email user
'emailuser'       => 'Zi onye á ózí-nsónùsòrò',
'emailpage'       => "Mé ọ'bànifé e-mailù",
'defemailsubject' => 'e-mail {{SITENAME}}',
'emailfrom'       => 'Onye banyere ya:',
'emailto'         => 'Onye o gi ru:',
'emailsubject'    => 'Gbàsịrị:',
'emailmessage'    => 'Ozi:',
'emailsend'       => 'Zí ozi',
'emailsent'       => 'E-mail zìrì',

# Watchlist
'watchlist'         => 'Ndetu ihem ne lé',
'mywatchlist'       => 'Ndetu ihem ne lé',
'watchlistfor2'     => 'Maka $1 $2',
'addedwatchtext'    => "Ihü \"[[:\$1]]\" à bányéré [[Special:Watchlist|ndétu ihe Í ne lé]].
Ihe gi gbanwe na ógè gi bya nà ihüá na ihü okwu ya gi di ndétu ngáhù, na ihü gi da na mkpụrụ édé '''sírí íke''' ímé [[Special:RecentChanges|ndétu gbanwere méré na ogè nso]] ka ȯ dí òfelè Í hü ya.",
'removedwatchtext'  => 'Ihü "[[:$1]]" à fwüó lá [[Special:Watchlist|ihe ndétu ihe Í ne lé]].',
'watch'             => 'Hü',
'watchthispage'     => 'Lèwá ihüá',
'unwatch'           => 'A hükwàlà',
'notanarticle'      => 'Búghị ihü ihe nọr',
'watchlist-details' => '{{PLURAL:$1|ihü $1|ihü $1}} nọr na ndétu ihe Í ne lé, nke à gúgị ihü okwu.',
'wlshowlast'        => 'Zi nke mbu àmànị $1 chi $2 $3',
'watchlist-options' => 'Nrọta ndetu nlènlé',

# Displayed when you click the "watch" button and it is in the process of watching
'watching'   => 'O na hü...',
'unwatching' => 'O mele ka o na á hü kwagi...',

'enotif_impersonal_salutation' => "ọ'bànifé {{SITENAME}}",
'changed'                      => 'gbanwere',
'created'                      => 'kèrè',
'enotif_subject'               => 'Ihü {{SITENAME}} $PAGETITLE à gálá $CHANGEDORCREATED nà áká $PAGEEDITOR',
'enotif_anon_editor'           => "ọ'bànifé ézíghị ihu $1",

# Delete
'deletepage'            => 'Kàchafu ihü',
'confirm'               => 'Kwèré',
'excontent'             => 'ihe nọr na ímé ya mbu bụ: "$1"',
'exblank'               => 'ihü gbàrà nkonko',
'delete-confirm'        => 'Kàcha "$1"',
'delete-legend'         => 'Kàcha',
'confirmdeletetext'     => 'Í gálá Í gbákashiá ihü na ákíkó mbu ya.
Biko sí nà ọ bụ ihe Í chọrọ, na Í mà ihe gi mè, na Í nè me ya kà yá na [[{{MediaWiki:Policy-url}}|òtù há nè mé ihe]] di óma.',
'actioncomplete'        => 'Ọ méchá',
'actionfailed'          => 'Òmùmẹ́ à daala',
'deletedtext'           => '"$1" à gbákáshíálá.
Lé $2 màkà okwu gbásárá ihe ọ gbakashiri màkà.',
'dellogpage'            => 'Ntínyé ngbákashị',
'deletecomment'         => 'Màkà:',
'deleteotherreason'     => 'Màkà ihe ozor kwa:',
'deletereasonotherlist' => 'Mgbághàpụtá ozor',

# Rollback
'rollback_short' => 'Fifié àzú',
'rollbacklink'   => 'fifié àzú',
'rollbackfailed' => 'Fifié na àzú dàrà',

# Protect
'protectlogpage'              => 'Ntínyé nke ncẹdolu',
'protectedarticle'            => 'chédòlù "[[$1]]"',
'modifiedarticleprotection'   => 'gbánwèrè íshí ncẹdolu màkà "[[$1]]"',
'protectcomment'              => 'Mgbághapụtà:',
'protectexpiry'               => 'Gbá ọ́kà:',
'protect_expiry_invalid'      => 'Ógẹ mgbe ó gị gbá ùkà adíghị ómá.',
'protect_expiry_old'          => 'Ógẹ mgbe ȯ gbàrà úkà à gafele.',
'protect-text'                => "Í nwèríkí lá mà Í gbanwe ncẹdolu ihü '''$1''' nke.",
'protect-locked-access'       => "Bùwá gi ènwéghị òdạ Í gbanwe ncẹdolu ihü.
Ngá bu ihe hé mèkwàrà nà ihü '''$1''':",
'protect-cascadeon'           => ' Ihüá cẹdolu màkà ȯ dị nà {{PLURAL:$1|ihü, nwéré|ihü, ndi nwéré}} cẹdolu mgbàwéré dí.
Í nwèríkí gbanwe cẹdolu ihüá, mànà ȯ gi métú ncẹdolu mgbàwéré.',
'protect-default'             => "Kwèré ọ'bànifé nílé",
'protect-fallback'            => 'Gí jí ọdà "$1"',
'protect-level-autoconfirmed' => "Kwàchí ndi ohürù na ndi ọ'bànifé a bághị",
'protect-level-sysop'         => 'Ndi íshí nani',
'protect-summary-cascade'     => 'mgbàwéré',
'protect-expiring'            => 'nà gbá ókà na $1 (UTC)',
'protect-expiring-local'      => 'gbáọ́kà na $1',
'protect-expiry-indefinite'   => 'àghọ́ta',
'protect-cascade'             => 'Ihü ha cẹdolu di na ime ihüá (ncẹdolu mgbàwéré)',
'protect-cantedit'            => 'Ì nwéghịkí gbanwe ncẹdolu ihü á, màkà Ì nwéghị ọdà Í rü ya.',
'protect-othertime'           => 'Ógẹ ozor',
'protect-othertime-op'        => 'ógẹ ozor',
'protect-otherreason-op'      => 'Mgbághàpụtá ozor',
'protect-expiry-options'      => 'àmànì 1:1 hour,chi 1:1 day,izù 1:1 week,izù 2:2 weeks,önwa1:1 month,önwa 3:3 months,önwa 6:6 months,afọr 1:1 year,ógè énwéghị ùbe:infinite',
'restriction-type'            => 'Ọdà:',
'restriction-level'           => 'Nke mgbáchí rùrù:',
'minimum-size'                => 'Ívù nke ntà',
'maximum-size'                => 'Ívù nke ukwu:',
'pagesize'                    => '(byte)',

# Restrictions (nouns)
'restriction-edit'   => 'Mèzi',
'restriction-move'   => 'Páfụ',
'restriction-create' => 'Ké',
'restriction-upload' => 'Tinyénélú',

# Restriction levels
'restriction-level-all' => 'ọtú nke ȯbulà',

# Undelete
'undeletebtn'               => 'Dòmárí àzụ́',
'undeletelink'              => 'lé/dosimá',
'undeleteviewlink'          => 'lé',
'undeletereset'             => "Mẹ̀wárí n'ísí",
'undeletecomment'           => 'Mgbághapụtà:',
'undelete-search-submit'    => 'Chọwa',
'undelete-show-file-submit' => 'Eeh',

# Namespace form on various pages
'namespace'      => 'Áhàámá:',
'invert'         => 'kwùtúárí ihe áká nọr',
'blanknamespace' => '(Ḿkpà)',

# Contributions
'contributions'       => "Ihe ọ'bànifé rürü",
'contributions-title' => "Orü ọ'bànifé nà $1",
'mycontris'           => 'Ihem mẹtụrụ na orürü',
'contribsub2'         => 'Maka $1 ($2)',
'uctop'               => '(ishi)',
'month'               => 'Shi önwa (na nke ndi mbu):',
'year'                => 'Shi afọr (na ndi nke mbu):',

'sp-contributions-newbies'  => "Zí orü áká ọ'bànifé ohúru náni",
'sp-contributions-blocklog' => 'kwụchi ntinyé',
'sp-contributions-deleted'  => "orü ọ'bànifé gbakashịrị",
'sp-contributions-uploads'  => 'tinyere na élu.',
'sp-contributions-logs'     => 'ndetu-nchétá',
'sp-contributions-talk'     => 'okwu',
'sp-contributions-search'   => 'Tuó ihe há rürü',
'sp-contributions-username' => "IP mà ọ bu áhà ọ'bànifé:",
'sp-contributions-submit'   => 'Chọwa',

# What links here
'whatlinkshere'            => 'Ihe na bia nga',
'whatlinkshere-title'      => 'Ihü ná gá "$1" shí jikodo',
'whatlinkshere-page'       => 'Ihü:',
'linkshere'                => "Ihüá na gá '''[[:$1]]''':",
'nolinkshere'              => "Ọ díghị ihü na jikodo gá '''[[:$1]]'''.",
'nolinkshere-ns'           => "Ọ díghị ihü na jikodo gá '''[[:$1]]''' na áhàámá nke Í chọrọ.",
'isredirect'               => 'ihü nke nkúfù',
'istemplate'               => 'ọ jè ákwúkwó usòrò',
'isimage'                  => 'jikodo nnunuuche',
'whatlinkshere-prev'       => '{{PLURAL:$1|nke dí nà àzú|$1 nke dí nà àzú}}',
'whatlinkshere-next'       => '{{PLURAL:$1|nke sọrọ|$1 nke sọrọ}}',
'whatlinkshere-links'      => ' jikodo',
'whatlinkshere-hideredirs' => '$1 nke kufùrù',
'whatlinkshere-hidetrans'  => '$1 ọ jè ákwúkwó usòrò',
'whatlinkshere-hidelinks'  => 'Jikodo $1',
'whatlinkshere-hideimages' => 'jikodo nhuunuche $1',
'whatlinkshere-filters'    => 'Nzàtà',

# Block/unblock
'block'                    => "Gbàchí ọ'bànifé",
'blockip'                  => "Gbàchí ọ'bànifé",
'blockip-title'            => "Gbàchí ọ'bànifé",
'blockip-legend'           => "Gbàchí ọ'bànifé",
'ipadressorusername'       => "IP mà ọ bu áhà ọ'bànifé:",
'ipbexpiry'                => 'Gbá okà:',
'ipbreason'                => 'Mgbághapụtà:',
'ipbreasonotherlist'       => 'Mgbághàpụtá ozor',
'ipbsubmit'                => "Kwàchí ọ'bànifé nkèá",
'ipbother'                 => 'Ógẹ ozor',
'ipboptions'               => 'àmànì 2:2 hours,chi 1:1 day,chi 3:3 days,izù 1:1 week,izù 2:2 weeks,önwa1:1 month,önwa 3:3 months,önwa 6:6 months,afọr 1:1 year,ógè énwéghị ùbe:infinite',
'ipbotheroption'           => 'nke ozor',
'ipb-confirm'              => 'Kwé mgbáchí',
'ipb-unblock-addr'         => 'Ákwàchịrị $1',
'ipb-unblock'              => "Ákwàchịrị áhà ọ'bànifé ma IP",
'unblockip'                => "Ákwàchịrị ọ'bànifé",
'unblocked'                => 'há kwàchịrị [[User:$1|$1]]',
'ipblocklist'              => "Ọ'bànifé kwáchírí",
'blocklist-target'         => 'Ẹ́té',
'blocklist-expiry'         => 'Gbá ọ́kà',
'ipblocklist-submit'       => 'Chọwa',
'infiniteblock'            => 'ébìébì ùdìdì',
'anononlyblock'            => 'anon. náni',
'emailblock'               => 'ha kwàchịrị e-mail',
'blocklink'                => 'mèché',
'unblocklink'              => 'a kwadokwàlà',
'change-blocklink'         => 'gbanwe ngwùgwù',
'contribslink'             => 'orürü',
'blocklogpage'             => 'Ndetù échìchè nke mbàchì',
'blocklogentry'            => 'kwụchi [[$1]] jí ógè ne $2 $3',
'unblocklogentry'          => 'àkwáchị gị $1',
'block-log-flags-nocreate' => "Í ké ọ'bànifé bàchìrì",
'block-log-flags-noemail'  => 'ha kwàchịrị e-mail',
'blockme'                  => 'Kwàchím',
'proxyblocksuccess'        => 'Ọméchá.',

# Developer tools
'lockdb'    => 'Gbàchí uche nsónùsòrò',
'unlockbtn' => 'Ágbàchịkwàlà uche nsónùsòrò',

# Move page
'move-page'               => 'Páfụ $1',
'move-page-legend'        => 'Páfù ihü',
'movepagetext'            => "Í jí ákwúkwó òchá nke di na àlà gi gȯwá ótù ihü áhà ozor, na ȯ gi kwáfu ákíkó mbu ya na áhà nke ohürù.
Íshí ihü nke ichié gi bu zi nkúfù gi gá áhà ohürù nke áhụ.
Í nwèríkí kúwárí nkúfù nke na ga áhà nke mbu na áká ya.
Ȯ bu na Í chȯgị, kpàchákwá ánya Í lé má màkà nkúfù na gbá [[Special:DoubleRedirects|abụọ]] ma [[Special:BrokenRedirects|nkúfù gbájírí]].
Ȯ dị na áká gi Í kpáchá ánya na jikodo na gá ébé o kwèshírí ga.

Chètákwá na ihü nke áhù '''ágághị''' a pú ȯ bu na ȯ dị ihü nwéré áhà áhù, bèelụ mà ȯ díghị ihe nọr ya na ímé ma ȯ bu nkúfù na onwé ya nke enweghị orürü nke mbu.
Ihe á fùtàrà na Í nwèríkí gọwáríá áhà ihü na nke mbu ya ȯ bu na Í gọrọ ọghọm, na Ì nwéghíkí dé na élú ihü di kwa.

'''Kpàchákwá Ntị!'''
Ihe á nwèríkí bu ngbanwe ukwu mákà ihü ne wu;
Biko kpàchá kwa ánya Í mà na ihe í ne mé na ógè gbárá mbu mgbè Í gí mé ya.",
'movepagetalktext'        => "Ihü owu ya gi fwüor na áká ya na ihü nke gárá '''bèelụ mà:'''
*Ihü okwu nke énwéghị ihe nọr na ímé ya na ȯ dị nà áhà ohürù nke áhù, mà
*Í piáfù igbé nọr nà àlà ngá.

Na nke, Í gi páfù na Í mékȯtá ihü nà onwé gi ọ bu nà Í chọrọ.",
'movearticle'             => 'Páfù ihü:',
'movenologin'             => 'I bátà bò',
'newtitle'                => 'Gá íshí édémédé nke:',
'move-watch'              => 'Lèmá ihü ó shị na ihü ȯ na gá',
'movepagebtn'             => 'Páfù ihü',
'pagemovedsub'            => 'Mpúzié ẹ meelá',
'movepage-moved'          => '\'\'\'"$1" páfùrù Í gá "$2"\'\'\'',
'articleexists'           => ' Ihü ótù nwèkwàrà áhà nke áhù, mà áhà Í chọrọ à búghị ézíboté.
Biko wèré áhà ozor.',
'talkexists'              => "'''Ihü na onwe ya páfùrù ǹkè ómá, mànà hè nweríkí puzié ihü okwu ya  màkà ótù ya dìkwà na íshí ihü nke òhúhru.
Biko tinyé ha nà áká gi.'''",
'movedto'                 => 'ó shifụrụ gá',
'movetalk'                => 'Páfù ihü okwu nke ya',
'move-subpages'           => 'Páfù ihü-n-ímé (nè rú $1)',
'move-talk-subpages'      => 'Páfù ihü-n-ímé nke ihü okwu (nè rú $1)',
'movepage-page-moved'     => 'Ihü $1 a páfùrù gá $2.',
'movepage-page-unmoved'   => 'Ihü $1 énweghịkị páfù gá $2.',
'movelogpage'             => 'Páfù ntínyé',
'movereason'              => 'Mgbághapụtà:',
'revertmove'              => 'gbanwe lá àzú',
'delete_and_move'         => 'Bakahia na puzie',
'delete_and_move_text'    => '== I kachafu gi me ==
Ebe ihü gé rú "[[:$1]]" di kwa.
I chorí kàchafu ya ka uzor mepo maka mpuzie ne me?',
'delete_and_move_confirm' => 'Eeh, kàchafu ihüa',
'immobile-source-page'    => 'Enwerịkị puzie ihüá.',
'move-leave-redirect'     => 'Háfụ nkufù na azu',

# Export
'export'            => 'Wefutárá ihü ime ihe ozor',
'exportcuronly'     => 'Tinyé nke mere ubüwá, o wughi akíkó mbu níle',
'export-submit'     => 'Dọwá fú',
'export-addcattext' => 'Tinyé ihü shi ébéanọr:',
'export-addcat'     => 'Tinyé',
'export-addnstext'  => 'Tinyé ihü shi amaáhà:',
'export-addns'      => 'Tinyé',
'export-download'   => 'Domá kà usòrò',

# Namespace 8 related
'allmessagesname'               => 'Áhà',
'allmessages-filter-legend'     => 'Nzàtà',
'allmessages-filter-unmodified' => 'Rübàlà',
'allmessages-filter-all'        => 'Haníle',
'allmessages-filter-modified'   => 'Mèrìrì',
'allmessages-language'          => 'Ásụ̀sụ̀:',
'allmessages-filter-submit'     => 'Gá',

# Thumbnails
'thumbnail-more' => 'Me ko bu ibù',
'filemissing'    => 'Usòrò è fwuólé',

# Special:Import
'import'                     => 'Gọbàtá ihü',
'importinterwiki'            => 'Ngọbàtá Transwiki',
'import-interwiki-source'    => 'Mkpòlógwù wiki/ihü:',
'import-interwiki-templates' => 'Bàtụcha átụ́ nile',
'import-interwiki-submit'    => 'Dọwá bànyé',
'import-upload-filename'     => 'Áhà usòrò:',
'import-comment'             => 'Okwu-nokwu:',
'importstart'                => 'Ógbȯbàtàlà ihü...',
'import-revision-count'      => '{{PLURAL:$1|orübà|orübà}} $1',
'importnopages'              => 'Ihü á díghị Í gọbàtá.',
'importhistoryconflict'      => 'Akíkó mbu na á lüogù nọr kwàrà (oweriki bu I tinyèrè ihü nka mbu)',
'import-token-mismatch'      => 'Ogẹ a fwuólé.
Biko meríáríá ozor.',

# Import log
'importlogpage' => 'Hubàtà ndetu',

# Tooltip help for the actions
'tooltip-pt-userpage'             => "Ihü ọ'bànifé gi",
'tooltip-pt-mytalk'               => 'Ihü akíkó gi',
'tooltip-pt-preferences'          => 'Otú Í shị na dose ihe gi',
'tooltip-pt-watchlist'            => 'Ndetu ihü Í ne lé màkà ihe gị gbanwe',
'tooltip-pt-mycontris'            => 'Ndetù ihe Í rürü',
'tooltip-pt-login'                => 'Anyi si ka Í gbanyé; chetákwá na nsogbu adighi I gbanye ma Í chógị gbànyé',
'tooltip-pt-logout'               => 'Fwuör',
'tooltip-ca-talk'                 => 'Akíkó maka ihe di na ihü nka',
'tooltip-ca-edit'                 => 'Í nwẹríkí rü na ihü nka. Biko jí mkpátá nlélé mgbe Í na domá ihüá',
'tooltip-ca-addsection'           => 'Binyíte nkeji ohúrù',
'tooltip-ca-viewsource'           => 'Ihü nke cẹdolu.
Í nwèríkí lé mkpụrụ ya',
'tooltip-ca-history'              => 'Orü ichié na ihüá',
'tooltip-ca-protect'              => 'Cẹdolu ihüá',
'tooltip-ca-unprotect'            => 'Gbánwe ncẹdo ihüá',
'tooltip-ca-delete'               => 'Bakashia ihüá',
'tooltip-ca-move'                 => 'Puzie ihüá',
'tooltip-ca-watch'                => 'Tìnyé ihü á na ndétu ihe Í ne lé',
'tooltip-ca-unwatch'              => 'Kwáfụ ihüá shí ndetu ihe m ne lé',
'tooltip-search'                  => 'Chọwa {{SITENAME}}',
'tooltip-search-go'               => 'Gá na ihü nwere kwa áhà nke ma o di',
'tooltip-search-fulltext'         => 'Chọwa na ihü maka mpkurụ okwu á',
'tooltip-p-logo'                  => 'Ga na ihü mbu',
'tooltip-n-mainpage'              => 'Ga na ihü mbu',
'tooltip-n-mainpage-description'  => 'Ga na ihü mbu',
'tooltip-n-portal'                => 'Maka orürü, gi ka Í nweríkí mé, ébé ha na tú ihe',
'tooltip-n-currentevents'         => 'Tuó ákíkó mbu màkà ihe ne me ubwá',
'tooltip-n-recentchanges'         => 'Ndetu ihe gbanwere na oge nsó na wiki',
'tooltip-n-randompage'            => 'Banyé ihü otu enweghi ishi',
'tooltip-n-help'                  => 'Ébé e shị amárá',
'tooltip-t-whatlinkshere'         => 'Détụ ihü wiki nílé na ga ngà',
'tooltip-t-recentchangeslinked'   => 'Ihe gbanwere na ihü jikodọrọ na ihü nke nà ógè nso',
'tooltip-feed-rss'                => 'Ntá RSS maka ihüá',
'tooltip-feed-atom'               => 'Nta Atom maka ihüá',
'tooltip-t-contributions'         => "Zí ndétu ihe ọ'bànifé nke rürü",
'tooltip-t-emailuser'             => "Zìrí ọ'bànifé nkeá ozi e-mail",
'tooltip-t-upload'                => 'Tịnyé ihe na nsónùsòrò',
'tooltip-t-specialpages'          => 'Ndetu ihü mkpà níle',
'tooltip-t-print'                 => 'Ihü nka nke Í nweríkí dótù',
'tooltip-t-permalink'             => 'Jikodo nke dìrì e dí nke na gá ngbàzì ihü nka',
'tooltip-ca-nstab-main'           => 'Zi ihe nor na ihüá',
'tooltip-ca-nstab-user'           => "Zi ihü ọ'bànifé",
'tooltip-ca-nstab-special'        => 'Ihü mkpà, a nweriki ru na ya onwe ya',
'tooltip-ca-nstab-project'        => 'Lé ihü hé chèdòlù',
'tooltip-ca-nstab-image'          => 'Zi ihü usòrò',
'tooltip-ca-nstab-template'       => 'Zi mkpurụ ihü',
'tooltip-ca-nstab-help'           => 'Zi ihü nkwádo',
'tooltip-ca-nstab-category'       => 'Zi ihü ébéanọr',
'tooltip-minoredit'               => 'Ká nke kà orü ntàkírí',
'tooltip-save'                    => 'Domá ihe í gbanwere',
'tooltip-preview'                 => 'Lètú ihe Í gbànwèrè, bíkó búzọr jí ihe á mgbe Í gi dọnyé!',
'tooltip-diff'                    => 'Zi ihe Í gbanwere na édémédé',
'tooltip-compareselectedversions' => 'Lé ihe di ichè na orü nke áká di na nke méré na ihü a',
'tooltip-watch'                   => 'Tìnyé ihü á na ndétu ihe Í ne lé',
'tooltip-rollback'                => '"Láázu" né kúfù orü dí na élú ihü á nke ọ\'bànifé onye ozor na mgbe Í kpàràrá mkpárá áhu',
'tooltip-undo'                    => '"Emekwàlà" nà kúfù orü nke na ȯ nè mépó akwukwo orü na ébé nlétū. Ȯ nè kwé ka Í tí ihe éjì èmé ya na édé ntà na àlà.',

# Attribution
'siteuser'    => "ọ'bànifé $1 {{SITENAME}}",
'others'      => 'nke ndi ozor',
'creditspage' => 'Nkó áhà ihüá',

# Spam protection
'spamprotectiontitle' => 'Ihe na zata maka cẹdolu ụrú',

# Info page
'pageinfo-header-edits' => 'Mèzí ịta',

# Image deletion
'filedeleteerror-short' => 'Nsògbú í kàcha usòrò: $1',

# Browsing diffs
'previousdiff' => 'Orü nke ichie',
'nextdiff'     => 'Orü nke ohúrù →',

# Media information
'file-info-size'       => '$1 × $2 pixel, ívù akwukwo orunótu: $3, MIME nke: $4',
'file-nohires'         => 'Nke káchá mmá na ányá àdíghị.',
'svg-long-desc'        => 'usòrò SVG, nà áhà pixel $1 × $2, ívụ usòrò: $3',
'show-big-image'       => 'Hü ya ka o dị',
'file-info-gif-looped' => 'etemte',

# Special:NewFiles
'newimages-legend' => 'Nzàtà',
'showhidebots'     => '(bot $1)',
'noimages'         => 'Ọ díghì ihe di ngá Í lé.',
'ilsubmit'         => 'Chọwa',
'bydate'           => 'shi afọ',

# Bad image list
'bad_image_list' => 'Ọtụ ȯ dị détùrù ngá:

Nání ndétu ihe (áhirí jí * bídó) dị na ihe ȯ chọrọ.
Jikodo bu nke mbu na áhìrì gí jikodo ya nà ȧkwúkwó orünotu di njö.
Jikodo nke gị byá àzú na áhìrì nke òfu á bu nke nwéríkí gáfè, díkà ihü ébé ȧkwúkwó orünotu áhu di ímé áhìrì ya.',

# Metadata
'metadata'          => 'Ómárí nso',
'metadata-help'     => 'Usòrò á nwèrè ụmà nke ozor, ọ ga dí na ȯ byàrà shí nsé nhuunuche nsónùsòrò mà ihe njè nsónùsòrò nke kéré mà nké tonyèrè ya na nsónùsòrò.
Ȯ bụ nà usòrò à gabnwere shí òtù ȯ di nà mgbe mbu, ótù ụmà àgághị è zí ya.',
'metadata-expand'   => 'Zi nkówá di ógólógó',
'metadata-collapse' => 'Zonari nkówá di ógólógó',
'metadata-fields'   => 'Ómárí nso nke nkeji nke nhuunuche détùrù na ozi nká gí banyé na nlé ihü nhuunuche mgbè ómárí nso mgbe àgàdà gi dátù.
Nke ozor gí zonari na áká onwe ha.
* make
* model
* datetimeoriginal
* exposuretime
* fnumber
* isospeedratings
* focallength
* artist
* copyright
* imagedescription
* gpslatitude
* gpslongitude
* gpsaltitude',

# EXIF tags
'exif-imagewidth'          => 'Àsáa',
'exif-imagelength'         => 'Ógólógó',
'exif-orientation'         => 'Ívú nà àsáa',
'exif-imagedescription'    => 'Íshí nhuunuche',
'exif-artist'              => 'Odé ákwụ́kwọ́',
'exif-exifversion'         => 'Ùdị Exif',
'exif-colorspace'          => 'Ámá àgwà',
'exif-exposuretime-format' => 'sec $1 ($2)',
'exif-fnumber'             => 'Ónúọgụgụ F',
'exif-brightnessvalue'     => 'Ọ̀chạ́ APEX',
'exif-lightsource'         => 'Mkpọlógwù ìfè',
'exif-flash'               => 'Gbu fịàfịà',
'exif-filesource'          => 'Mkpọ̀lọ́gwụ̀ usòrò',
'exif-citydest'            => 'Ámá ukwu ziri',
'exif-writer'              => 'Òdìdè',
'exif-languagecode'        => 'Ásụ̀sụ̀',
'exif-iimcategory'         => 'Ébéonọr',
'exif-label'               => 'Ọdụ',

'exif-orientation-1' => 'Nkịtị',

'exif-exposureprogram-1' => 'Ònyèmáká',

'exif-subjectdistance-value' => 'meter $1',

'exif-meteringmode-0'   => 'Nke námaghị',
'exif-meteringmode-1'   => 'Nà nke ñkịtị',
'exif-meteringmode-3'   => 'Ntụpọ',
'exif-meteringmode-5'   => 'Nnòmi',
'exif-meteringmode-6'   => 'Mmẹtụ',
'exif-meteringmode-255' => 'Nke ozor',

'exif-lightsource-0'  => 'Nke námaghị',
'exif-lightsource-1'  => 'Nta ubochi',
'exif-lightsource-4'  => 'Gbu fịàfịà',
'exif-lightsource-9'  => 'Iru igwē di ómá',
'exif-lightsource-10' => 'Iru igwē di ulùkpù ulùkpù',
'exif-lightsource-11' => 'Ǹdò',

'exif-focalplaneresolutionunit-2' => 'inch',

'exif-scenecapturetype-1' => "Mkpọlógwù'àlà",

'exif-gaincontrol-0' => 'Efù',

'exif-contrast-0' => 'Nkịtị',
'exif-contrast-1' => 'Bịàlịị',
'exif-contrast-2' => 'Kàràká',

'exif-saturation-0' => 'Nkịtị',

'exif-sharpness-0' => 'Nkịtị',
'exif-sharpness-1' => 'Bịàlịị',
'exif-sharpness-2' => 'Kàràká',

'exif-subjectdistancerange-0' => 'Nke námaghị',
'exif-subjectdistancerange-2' => 'Mèchí ǹyò',

# Pseudotags used for GPSLatitudeRef and GPSDestLatitudeRef
'exif-gpslatitude-n' => 'Asá olile anyanwu',
'exif-gpslatitude-s' => 'Asá nleda anyanwu',

# Pseudotags used for GPSLongitudeRef and GPSDestLongitudeRef
'exif-gpslongitude-e' => 'Ógólógó owuwa anyanwu',
'exif-gpslongitude-w' => 'Ógólógó odida anyanwu',

# Pseudotags used for GPSSpeedRef
'exif-gpsspeed-n' => 'Knot',

# Pseudotags used for GPSDestDistanceRef
'exif-gpsdestdistance-k' => 'Kilomitas',
'exif-gpsdestdistance-m' => 'Maisu',

'exif-gpsdop-good'     => 'Ọma ($1)',
'exif-gpsdop-moderate' => 'Dịtụnma ($1)',
'exif-gpsdop-fair'     => 'Òzú ($1)',

'exif-dc-date'      => 'Ngụụ̀bọ̀chì',
'exif-dc-publisher' => 'Ọ̀má ákwụ́kwọ́',
'exif-dc-rights'    => 'Nkwènyé',

'exif-rating-rejected' => 'Gbụ́fụ̀rụ̀',

'exif-iimcategory-clj' => 'Nsọ na iwú',
'exif-iimcategory-edu' => 'Ńkúzí',
'exif-iimcategory-evn' => 'Èzí',
'exif-iimcategory-hth' => 'Wíké',
'exif-iimcategory-hum' => 'Mmasịrị madu',
'exif-iimcategory-lab' => 'Íké aka',
'exif-iimcategory-pol' => 'Ọ́chị́',
'exif-iimcategory-spo' => 'Ụ̀gbàmà',
'exif-iimcategory-war' => 'Ághá, ọ̀gụ̀ na ághàrà',
'exif-iimcategory-wea' => 'Ihü ígwe',

'exif-urgency-normal' => 'Nkịtị ($1)',
'exif-urgency-low'    => 'Nàlà ($1)',
'exif-urgency-high'   => 'Nélú ($1)',

# External editor support
'edit-externally'      => 'Rüo na élú usòrò nke na ngwa ọrụ nsónùsòrò nke ọzȯ',
'edit-externally-help' => '(Lé nà [https://www.mediawiki.org/wiki/Manual:External_editors nkụzí mbídó] màkà nkúzí ozor)',

# 'all' in various places, this might be different for inflected languages
'watchlistall2' => 'nke níle',
'namespacesall' => 'nke níle',
'monthsall'     => 'nke níle',
'limitall'      => 'nke níle',

# Delete conflict
'recreate' => 'Ké ya ohúrù',

# action=purge
'confirm_purge_button' => 'Ngwanu',

# action=watch/unwatch
'confirm-watch-button'   => 'Ngwanu',
'confirm-unwatch-button' => 'Ngwanu',

# Multipage image navigation
'imgmultipageprev' => 'ihü na àzú',
'imgmultipagenext' => 'ihü nke di nso →',
'imgmultigo'       => 'Gá!',
'imgmultigoto'     => 'Gá na ihü $1',

# Table pager
'ascending_abbrev'         => 'heé élu',
'descending_abbrev'        => 'ndạtạ',
'table_pager_next'         => 'Ihü sò',
'table_pager_prev'         => 'Ihü na àzú',
'table_pager_first'        => 'Ihü mbu',
'table_pager_last'         => 'Ihü lara azu',
'table_pager_limit'        => 'Zí nke $1 màkà ihe na ótù ihü',
'table_pager_limit_label'  => 'Ihe ga di na ótù ihü:',
'table_pager_limit_submit' => 'Gá',
'table_pager_empty'        => 'Odígị ihe fútárá',

# Auto-summaries
'autosumm-blank' => 'Melá ihü ochá',
'autosumm-new'   => "Jiri '$1' kere ihü",

# Live preview
'livepreview-loading' => 'Ọ biágó...',
'livepreview-ready'   => 'O na biá... Ojikobala!',

# Watchlist editor
'watchlistedit-normal-title' => 'Rüó na ndétu ihe Í nè lé',
'watchlistedit-raw-titles'   => 'Ishi edemede:',
'watchlistedit-raw-submit'   => 'Kuwaria ndetu ihem ne lé',

# Watchlist editing tools
'watchlisttools-view' => 'Zi ihe gbanwere dí mkpà na ngá',
'watchlisttools-edit' => 'Lé na rü na ndetù ńlé',
'watchlisttools-raw'  => 'Rüo ndetù nlènlé mèpòrò',

# Special:Version
'version'                   => 'Ùdị',
'version-specialpages'      => 'Ihü mkpà',
'version-skins'             => 'Akpụkpọ',
'version-other'             => 'Nke ozor',
'version-hooks'             => 'Nyazo',
'version-hook-name'         => 'Áhà nyazo',
'version-hook-subscribedby' => 'Dọkpụrụ shì',
'version-version'           => '(Ùdị $1)',
'version-license'           => 'Íwú Ǹkwé',
'version-software-product'  => 'Nfófụtá',
'version-software-version'  => 'Ùdị',

# Special:FilePath
'filepath'        => 'Uzọ usòrò',
'filepath-page'   => 'Usòrò:',
'filepath-submit' => 'Gá',

# Special:FileDuplicateSearch
'fileduplicatesearch-filename' => 'Áhà usòrò:',
'fileduplicatesearch-submit'   => 'Chọwa',

# Special:SpecialPages
'specialpages'                 => 'Ihü mkpà',
'specialpages-group-other'     => 'Ihü mkpà nke ozor',
'specialpages-group-login'     => 'Banyé / ké buwa',
'specialpages-group-users'     => "Ọ'bànifé na íwú ihe nkwé",
'specialpages-group-highuse'   => 'Ihü éjị áká nke ukwu',
'specialpages-group-pages'     => 'Ndétu nke ihü',
'specialpages-group-pagetools' => 'Ngwa ihü',
'specialpages-group-wiki'      => 'Ùmá Wiki na ngwa ọru ya',
'specialpages-group-redirects' => 'Na kufù ihü mkpà',
'specialpages-group-spam'      => 'Ngwa ụrú',

# Special:BlankPage
'blankpage' => 'Ihü ochá',

# Special:Tags
'tags'                    => 'Ọdụ gbanwere di ndu',
'tag-filter'              => '[[Special:Tags|Ọdọ]] nzata:',
'tag-filter-submit'       => 'Nzàtà',
'tags-title'              => 'Ọdụ',
'tags-tag'                => 'Áhà ọdụ',
'tags-display-header'     => 'Ọdịdị na ndétu ngbanwe',
'tags-description-header' => 'Nkȯwá nke ukwu màkà íshí na ọdụ',
'tags-hitcount-header'    => 'Gbanwere nwéré ọdụ',
'tags-edit'               => 'mèzi',
'tags-hitcount'           => '$1 {{PLURAL:$1|gbanwere|gbanwere}}',

# Special:ComparePages
'comparepages'     => 'Má àtù ihü',
'compare-selector' => 'Má àtù orü dírí na élú ihü',
'compare-page1'    => 'Ihü 1',
'compare-page2'    => 'Ihü 2',
'compare-rev1'     => 'Orübà 1',
'compare-rev2'     => 'Orübà 2',
'compare-submit'   => 'Má àtù',

# Database error messages
'dberr-header'   => 'Wiki nka nwere nsogbu',
'dberr-problems' => 'Ndó! Ámá nka nwere nsogbu ime ime.',

# HTML forms
'htmlform-required'            => 'Ọgụgụ nke gi dị',
'htmlform-submit'              => 'Dànyé',
'htmlform-reset'               => 'Emekwàlà gbanwere',
'htmlform-selectorother-other' => 'Nke ozor',

# New logging system
'revdelete-content-hid' => 'ihe zọ̀nàri',

# Feedback
'feedback-message' => 'Ozi:',
'feedback-close'   => 'Ọméchá.',

);
